@@ -1,5 +1,5 @@
 /***************************************************************************
-                          addlinkdialog.h  -  K Desktop Planetarium
+                          addlinQDialog  -  K Desktop Planetarium
                              -------------------
     begin                : Sun Oct 21 2001
     copyright            : (C) 2001 by Jason Harris
@@ -19,9 +19,9 @@
 #define ADDLINKDIALOG_H_
 
 #include <QVBoxLayout>
-#include <kdialog.h>
+#include <QDialog>
 #include <klineedit.h>
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "ui_addlinkdialog.h"
 
@@ -34,17 +34,18 @@ public:
 };
 
 /**
-  *@class Simple dialog for adding a custom URL to a popup menu.
+  *@class AddLinkDialog
+  *  AddLinkDialog is a simple dialog for adding a custom URL to a popup menu.
   *@author Jason Harris
   *@version 1.0
   */
-class AddLinkDialog : public KDialog  {
+class AddLinkDialog : public QDialog  {
     Q_OBJECT
 public:
     /**
       *Constructor. 
     	*/
-    explicit AddLinkDialog( QWidget* parent = 0, const QString &oname=i18n("object") );
+    explicit AddLinkDialog( QWidget* parent = 0, const QString &oname=xi18n("object") );
 
     /**
       *Destructor (empty) 
