@@ -22,17 +22,16 @@
 #include <QPainter>
 #include <QTextStream>
 #include <QPaintEvent>
+#include <QDebug>
+#include <QPushButton>
+#include <QComboBox>
+#include <QDoubleSpinBox>
+#include <QLineEdit>
 
-#include <kactioncollection.h>
-#include <klocale.h>
-#include <kdebug.h>
-#include <kpushbutton.h>
+#include <KActionCollection>
+#include <KLocalizedString>
 #include <kcolorbutton.h>
-#include <kcombobox.h>
-#include <knuminput.h>
-#include <klineedit.h>
-#include <kmessagebox.h>
-#include <kstandarddirs.h>
+#include <KMessageBox>
 
 #include "kstars.h"
 #include "kstarsdata.h"
@@ -45,9 +44,9 @@ int FOVDialog::fovID = -1;
 
 namespace {
     // Try to convert text in KLine edit to double
-    inline double textToDouble(const KLineEdit* edit, bool* ok = 0)
+    inline double textToDouble(const QLineEdit* edit, bool* ok = 0)
     {
-        return edit->text().replace( KGlobal::locale()->decimalSymbol(), "." ).toDouble(ok);
+        return edit->text().replace( QLocale().decimalPoint(), "." ).toDouble(ok);
     }
 
     // Extract FOV from QListWidget. No checking is done
@@ -59,7 +58,7 @@ namespace {
     // Convert double to QString 
     QString toString(double x, int precision = 2)
     {
-        return QString::number(x, 'f', precision).replace( '.', KGlobal::locale()->decimalSymbol() );
+        return QString::number(x, 'f', precision).replace( '.', QLocale().decimalPoint() );
     }
 }
 
@@ -74,16 +73,24 @@ NewFOVUI::NewFOVUI( QWidget *parent ) : QFrame( parent ) {
 
 //---------FOVDialog---------------//
 FOVDialog::FOVDialog( QWidget* p ) :
-    KDialog( p )
+    QDialog( p )
 {
     // Register FOV* data type
     if( fovID == -1 )
         fovID = qRegisterMetaType<FOV*>("FOV*");
     fov = new FOVDialogUI( this );
-    setMainWidget( fov );
-    setCaption( i18n( "Set FOV Indicator" ) );
-    setButtons( KDialog::Ok | KDialog::Cancel );
-    
+
+    setWindowTitle( xi18n( "Set FOV Indicator" ) );
+
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    mainLayout->addWidget(fov);
+    setLayout(mainLayout);
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Close);
+    mainLayout->addWidget(buttonBox);
+    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+    connect(buttonBox, SIGNAL(rejected()), this, SLOT(close()));
+
     connect( fov->FOVListBox,   SIGNAL( currentRowChanged( int ) ), SLOT( slotSelect( int ) ) );
     connect( fov->NewButton,    SIGNAL( clicked() ), SLOT( slotNewFOV() ) );
     connect( fov->EditButton,   SIGNAL( clicked() ), SLOT( slotEditFOV() ) );
@@ -168,12 +175,22 @@ void FOVDialog::slotRemoveFOV() {
 //-------------NewFOV------------------//
 
 NewFOV::NewFOV( QWidget *parent, const FOV* fov ) :
-    KDialog( parent ), f()
+    QDialog( parent ), f()
 {
     ui = new NewFOVUI( this );
-    setMainWidget( ui );
-    setCaption( i18n( "New FOV Indicator" ) );
-    setButtons( KDialog::Ok|KDialog::Cancel );
+
+    setWindowTitle( xi18n( "New FOV Indicator" ) );
+
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    mainLayout->addWidget(ui);
+    setLayout(mainLayout);
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    mainLayout->addWidget(buttonBox);
+    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+
+    okB = buttonBox->button(QDialogButtonBox::Ok);
 
     // Initialize FOV if required
     if( fov != 0 ) {
@@ -207,30 +224,30 @@ NewFOV::NewFOV( QWidget *parent, const FOV* fov ) :
     connect( ui->ComputeTLengthFromFNum2, SIGNAL( clicked() ), SLOT( slotComputeTelescopeFL() ) );
 
     // Populate eyepiece AFOV options. The userData field contains the apparent FOV associated with that option
-    ui->EyepieceAFOV->insertItem( 0, i18nc("Specify the apparent field of view (AFOV) manually", "Specify AFOV"), -1 );
-    ui->EyepieceAFOV->addItem( i18nc("Eyepiece Design / Brand / Name; Optional", "Ramsden (Typical)"), 30 );
-    ui->EyepieceAFOV->addItem( i18nc("Eyepiece Design / Brand / Name; Optional", "Orthoscopic (Typical)"), 45 );
-    ui->EyepieceAFOV->addItem( i18nc("Eyepiece Design / Brand / Name; Optional", "Ploessl (Typical)"), 50 );
-    ui->EyepieceAFOV->addItem( i18nc("Eyepiece Design / Brand / Name; Optional", "Erfle (Typical)"), 60 );
-    ui->EyepieceAFOV->addItem( i18nc("Eyepiece Design / Brand / Name; Optional", "Tele Vue Radian"), 60 );
-    ui->EyepieceAFOV->addItem( i18nc("Eyepiece Design / Brand / Name; Optional", "Baader Hyperion"), 68 );
-    ui->EyepieceAFOV->addItem( i18nc("Eyepiece Design / Brand / Name; Optional", "Tele Vue Panoptic"), 68 );
-    ui->EyepieceAFOV->addItem( i18nc("Eyepiece Design / Brand / Name; Optional", "Tele Vue Delos"), 72 );
-    ui->EyepieceAFOV->addItem( i18nc("Eyepiece Design / Brand / Name; Optional", "Meade UWA"), 82 );
-    ui->EyepieceAFOV->addItem( i18nc("Eyepiece Design / Brand / Name; Optional", "Tele Vue Nagler"), 82 );
-    ui->EyepieceAFOV->addItem( i18nc("Eyepiece Design / Brand / Name; Optional", "Tele Vue Ethos (Typical)"), 100 );
+    ui->EyepieceAFOV->insertItem( 0, xi18nc("Specify the apparent field of view (AFOV) manually", "Specify AFOV"), -1 );
+    ui->EyepieceAFOV->addItem( xi18nc("Eyepiece Design / Brand / Name; Optional", "Ramsden (Typical)"), 30 );
+    ui->EyepieceAFOV->addItem( xi18nc("Eyepiece Design / Brand / Name; Optional", "Orthoscopic (Typical)"), 45 );
+    ui->EyepieceAFOV->addItem( xi18nc("Eyepiece Design / Brand / Name; Optional", "Ploessl (Typical)"), 50 );
+    ui->EyepieceAFOV->addItem( xi18nc("Eyepiece Design / Brand / Name; Optional", "Erfle (Typical)"), 60 );
+    ui->EyepieceAFOV->addItem( xi18nc("Eyepiece Design / Brand / Name; Optional", "Tele Vue Radian"), 60 );
+    ui->EyepieceAFOV->addItem( xi18nc("Eyepiece Design / Brand / Name; Optional", "Baader Hyperion"), 68 );
+    ui->EyepieceAFOV->addItem( xi18nc("Eyepiece Design / Brand / Name; Optional", "Tele Vue Panoptic"), 68 );
+    ui->EyepieceAFOV->addItem( xi18nc("Eyepiece Design / Brand / Name; Optional", "Tele Vue Delos"), 72 );
+    ui->EyepieceAFOV->addItem( xi18nc("Eyepiece Design / Brand / Name; Optional", "Meade UWA"), 82 );
+    ui->EyepieceAFOV->addItem( xi18nc("Eyepiece Design / Brand / Name; Optional", "Tele Vue Nagler"), 82 );
+    ui->EyepieceAFOV->addItem( xi18nc("Eyepiece Design / Brand / Name; Optional", "Tele Vue Ethos (Typical)"), 100 );
 
     connect( ui->EyepieceAFOV, SIGNAL( currentIndexChanged( int ) ), SLOT( slotEyepieceAFOVChanged( int ) ) );
 
-    ui->LinearFOVDistance->insertItem( 0, i18n( "1000 yards" ) );
-    ui->LinearFOVDistance->insertItem( 1, i18n( "1000 meters" ) );
+    ui->LinearFOVDistance->insertItem( 0, xi18n( "1000 yards" ) );
+    ui->LinearFOVDistance->insertItem( 1, xi18n( "1000 meters" ) );
     connect( ui->LinearFOVDistance, SIGNAL( currentIndexChanged( int ) ), SLOT( slotBinocularFOVDistanceChanged( int ) ) );
 
     slotUpdateFOV();
 }
 
 void NewFOV::slotBinocularFOVDistanceChanged( int index ) {
-    QString text = (index == 0  ? i18n("feet") : i18n("meters"));
+    QString text = (index == 0  ? xi18n("feet") : xi18n("meters"));
     ui->LabelUnits->setText( text );
 }
 
@@ -254,7 +271,7 @@ void NewFOV::slotUpdateFOV() {
     f.setShape( ui->ShapeBox->currentIndex() );
     f.setColor( ui->ColorButton->color().name() );
 
-    enableButtonOk( !f.name().isEmpty() && okX && okY );
+    okB->setEnabled(!f.name().isEmpty() && okX && okY );
     
     ui->ViewBox->setFOV( &f );
     ui->ViewBox->update();
@@ -266,10 +283,11 @@ void NewFOV::slotComputeFOV() {
         ui->FOVEditY->setText( ui->FOVEditX->text() );
     }
     else if ( sender() == ui->ComputeCameraFOV && ui->TLength2->value() > 0.0 ) {
-        double sx = (double) ui->ChipSize->value() * 3438.0 / ui->TLength2->value();
-        const double aspectratio = 3.0/2.0; // Use the default aspect ratio for DSLRs / Film (i.e. 3:2)
+        double sx = (double) ui->ChipWidth->value() * 3438.0 / ui->TLength2->value();
+        double sy = (double) ui->ChipHeight->value() * 3438.0 / ui->TLength2->value();
+        //const double aspectratio = 3.0/2.0; // Use the default aspect ratio for DSLRs / Film (i.e. 3:2)
         ui->FOVEditX->setText( toString(sx) );
-        ui->FOVEditY->setText( toString(sx / aspectratio) );
+        ui->FOVEditY->setText( toString(sy) );
     }
     else if ( sender() == ui->ComputeHPBW && ui->RTDiameter->value() > 0.0 && ui->WaveLength->value() > 0.0 ) {
         ui->FOVEditX->setText( toString(34.34 * 1.2 * ui->WaveLength->value() / ui->RTDiameter->value()) );
@@ -311,26 +329,39 @@ void NewFOV::slotComputeTelescopeFL() {
 //-------------TelescopeFL------------------//
 
 TelescopeFL::TelescopeFL( QWidget *parent ) :
-    KDialog( parent ), aperture( 0 ), fNumber( 0 ), apertureUnit( 0 ) {
+    QDialog( parent ), aperture( 0 ), fNumber( 0 ), apertureUnit( 0 ) {
 
-    setCaption( i18n( "Telescope Focal Length Calculator" ) );
-    setButtons( KDialog::Ok|KDialog::Cancel );
+    setWindowTitle( xi18n( "Telescope Focal Length Calculator" ) );
 
-    QWidget *mainWidget = new QWidget( this );
-    QGridLayout *mainLayout = new QGridLayout( mainWidget );
-    mainWidget->setLayout( mainLayout );
-    setMainWidget( mainWidget );
+    //QWidget *mainWidget = new QWidget( this );
+    QGridLayout *mainLayout = new QGridLayout( this );
+    setLayout( mainLayout );
 
-    aperture = new KDoubleNumInput( 0.0, 100000.0, 0.0, this, 0.1, 2 );
-    fNumber = new KDoubleNumInput( 0.0, 99.9, 0.0, this, 0.1, 2 );
-    apertureUnit = new KComboBox( this );
-    apertureUnit->insertItem( 0, i18nc("millimeters", "mm") );
-    apertureUnit->insertItem( 1, i18n("inch") );
-    mainLayout->addWidget( new QLabel( i18n("Aperture diameter: "), this ), 0, 0 );
+    aperture = new QDoubleSpinBox();
+    aperture->setRange(0.0, 100000.0);
+    aperture->setDecimals(2);
+    aperture->setSingleStep(0.1);
+
+    fNumber = new QDoubleSpinBox();
+    fNumber->setRange(0.0, 99.9);
+    fNumber->setDecimals(2);
+    fNumber->setSingleStep(0.1);
+
+    apertureUnit = new QComboBox( this );
+    apertureUnit->insertItem( 0, xi18nc("millimeters", "mm") );
+    apertureUnit->insertItem( 1, xi18n("inch") );
+
+    mainLayout->addWidget( new QLabel( xi18n("Aperture diameter: "), this ), 0, 0 );
     mainLayout->addWidget( aperture, 0, 1 );
     mainLayout->addWidget( apertureUnit, 0, 2 );
-    mainLayout->addWidget( new QLabel( i18nc("F-Number or F-Ratio of optical system", "F-Number: "), this ), 1, 0 );
+    mainLayout->addWidget( new QLabel( xi18nc("F-Number or F-Ratio of optical system", "F-Number: "), this ), 1, 0 );
     mainLayout->addWidget( fNumber, 1, 1 );
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    mainLayout->addWidget(buttonBox);
+    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
+    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+
     show();
 }
 
@@ -341,4 +372,4 @@ double TelescopeFL::computeFL() const {
 
 unsigned int FOVDialog::currentItem() const { return fov->FOVListBox->currentRow(); }
 
-#include "fovdialog.moc"
+
