@@ -15,15 +15,16 @@
 #include "guide/guider.h"
 #include "Options.h"
 
-
 #include <KMessageBox>
 #include <KLed>
+#include <KLocalizedString>
 
 #include "indi/driverinfo.h"
 #include "fitsviewer/fitsviewer.h"
 #include "fitsviewer/fitsview.h"
 
 #include "guide/rcalibration.h"
+#include "guideadaptor.h"
 
 #include <basedevice.h>
 
@@ -34,6 +35,9 @@ Guide::Guide() : QWidget()
 {
     setupUi(this);
 
+    new GuideAdaptor(this);
+    QDBusConnection::sessionBus().registerObject("/KStars/Ekos/Guide",  this);
+
     currentCCD = NULL;
     currentTelescope = NULL;
     ccd_hor_pixel =  ccd_ver_pixel =  focal_length =  aperture = -1;
@@ -46,6 +50,8 @@ Guide::Guide() : QWidget()
     AODriver= NULL;
     GuideDriver=NULL;
 
+    guideDeviationRA = guideDeviationDEC = 0;
+
     tabWidget = new QTabWidget(this);
 
     tabLayout->addWidget(tabWidget);
@@ -58,10 +64,10 @@ Guide::Guide() : QWidget()
     connect(pmath, SIGNAL(newAxisDelta(double,double)), this, SLOT(updateGuideDriver(double,double)));
 
     calibration = new rcalibration(this);
-    calibration->set_math(pmath);
+    calibration->setMathObject(pmath);
 
     guider = new rguider(this);
-    guider->set_math(pmath);
+    guider->setMathObject(pmath);
 
     connect(guider, SIGNAL(ditherToggled(bool)), this, SIGNAL(ditherToggled(bool)));
     connect(guider, SIGNAL(autoGuidingToggled(bool,bool)), this, SIGNAL(autoGuidingToggled(bool,bool)));
@@ -120,6 +126,18 @@ void Guide::setTelescope(ISD::GDInterface *newTelescope)
 
 }
 
+bool Guide::setCCD(QString device)
+{
+    for (int i=0; i < guiderCombo->count(); i++)
+        if (device == guiderCombo->itemText(i))
+        {
+            checkCCD(i);
+            return true;
+        }
+
+    return false;
+}
+
 void Guide::checkCCD(int ccdNum)
 {
     if (ccdNum == -1)
@@ -231,18 +249,18 @@ void Guide::updateGuideParams()
 
         if (targetChip == NULL)
         {
-            appendLogText(i18n("Connection to the guide CCD is lost."));
+            appendLogText(xi18n("Connection to the guide CCD is lost."));
             return;
         }
 
         emit guideChipUpdated(targetChip);
 
-        guider->set_target_chip(targetChip);
+        guider->setTargetChip(targetChip);
 
         if (targetChip->getFrame(&x,&y,&w,&h))
             pmath->set_video_params(w, h);
 
-        guider->fill_interface();
+        guider->setInterface();
 
     }
 }
@@ -267,7 +285,7 @@ void Guide::addST4(ISD::ST4 *newST4)
 void Guide::setAO(ISD::ST4 *newAO)
 {
     AODriver = newAO;
-    guider->set_ao(true);
+    guider->setAO(true);
 }
 
 bool Guide::capture()
@@ -275,7 +293,7 @@ bool Guide::capture()
     if (currentCCD == NULL)
         return false;
 
-    double seqExpose = exposureSpin->value();
+    double seqExpose = exposureIN->value();
 
     ISD::CCDChip *targetChip = currentCCD->getChip(useGuideHead ? ISD::CCDChip::GUIDE_CCD : ISD::CCDChip::PRIMARY_CCD);
 
@@ -283,15 +301,15 @@ bool Guide::capture()
 
     if (currentCCD->isConnected() == false)
     {
-        appendLogText(i18n("Error: Lost connection to CCD."));
+        appendLogText(xi18n("Error: Lost connection to CCD."));
         return false;
     }
 
     //If calibrating, reset frame
-    if (calibration->get_calibation_stage() == rcalibration::CAL_CAPTURE_IMAGE)
+    if (calibration->getCalibrationStage() == rcalibration::CAL_CAPTURE_IMAGE)
     {
         targetChip->resetFrame();
-        guider->set_subframed(false);
+        guider->setSubFramed(false);
     }
 
     // Exposure changed, take a new dark
@@ -300,20 +318,23 @@ bool Guide::capture()
         darkExposure = seqExpose;
         targetChip->setFrameType(FRAME_DARK);
 
-        KMessageBox::information(NULL, i18n("If the guider camera if not equipped with a shutter, cover the telescope or camera in order to take a dark exposure."), i18n("Dark Exposure"), "dark_exposure_dialog_notification");
+        if (calibration->isAutoCalibration() == false)
+            KMessageBox::information(NULL, xi18n("If the guider camera if not equipped with a shutter, cover the telescope or camera in order to take a dark exposure."), xi18n("Dark Exposure"), "dark_exposure_dialog_notification");
 
         connect(currentCCD, SIGNAL(BLOBUpdated(IBLOB*)), this, SLOT(newFITS(IBLOB*)));
         targetChip->capture(seqExpose);
 
-        appendLogText(i18n("Taking a dark frame. "));
+        appendLogText(xi18n("Taking a dark frame. "));
 
         return true;
     }
 
     targetChip->setCaptureMode(FITS_GUIDE);
     targetChip->setFrameType(ccdFrame);
+    if (darkImage == NULL || calibration->useDarkFrame() == false)
+        targetChip->setCaptureFilter((FITSScale) filterCombo->currentIndex());
 
-    if (guider->is_guiding())
+    if (guider->isGuiding())
     {
          if (guider->isRapidGuide() == false)
              connect(currentCCD, SIGNAL(BLOBUpdated(IBLOB*)), this, SLOT(newFITS(IBLOB*)));
@@ -348,7 +369,7 @@ void Guide::newFITS(IBLOB *bp)
             capture();
         }
         else
-            appendLogText(i18n("Dark frame processing failed."));
+            appendLogText(xi18n("Dark frame processing failed."));
 
        return;
     }
@@ -358,29 +379,27 @@ void Guide::newFITS(IBLOB *bp)
     if (targetImage == NULL)
     {
         pmath->set_image(NULL);
-        guider->set_image(NULL);
-        calibration->set_image(NULL);
+        guider->setImage(NULL);
+        calibration->setImage(NULL);
         return;
     }
 
-    FITSImage *image_data = targetImage->getImageData();
+    FITSData *image_data = targetImage->getImageData();
 
     if (image_data == NULL)
         return;
 
-    if (darkImage)
-        image_data->subtract(darkImage->getImageBuffer());
-
-    if (filterCombo->currentIndex() != -1)
+    if (darkImage && darkImage->getImageBuffer() != image_data->getDarkFrame())
     {
+        image_data->setDarkFrame(darkImage->getImageBuffer());
         image_data->applyFilter((FITSScale) filterCombo->currentIndex());
         targetImage->rescale(ZOOM_KEEP_LEVEL);
         targetImage->updateFrame();
     }
 
     pmath->set_image(targetImage);
-    guider->set_image(targetImage);
-    calibration->set_image(targetImage);
+    guider->setImage(targetImage);
+    calibration->setImage(targetImage);
 
     fv->show();
 
@@ -390,32 +409,32 @@ void Guide::newFITS(IBLOB *bp)
         return;
     }
 
-    if (guider->is_dithering())
+    if (guider->isDithering())
     {
         pmath->do_processing();
         if (guider->dither() == false)
         {
-            appendLogText(i18n("Dithering failed. Autoguiding aborted."));
+            appendLogText(xi18n("Dithering failed. Autoguiding aborted."));
             guider->abort();
             emit ditherFailed();
         }
     }
-    else if (guider->is_guiding())
+    else if (guider->isGuiding())
     {
         guider->guide();
 
-         if (guider->is_guiding())
+         if (guider->isGuiding())
             capture();
     }
-    else if (calibration->is_calibrating())
+    else if (calibration->isCalibrating())
     {
         GuideDriver = ST4Driver;
         pmath->do_processing();
-        calibration->process_calibration();
+        calibration->processCalibration();
 
-         if (calibration->is_finished())
+         if (calibration->isCalibrationComplete())
          {
-             guider->set_ready(true);
+             guider->setReady(true);
              tabWidget->setTabEnabled(1, true);
              emit guideReady();
          }
@@ -427,7 +446,7 @@ void Guide::newFITS(IBLOB *bp)
 void Guide::appendLogText(const QString &text)
 {
 
-    logText.insert(0, i18nc("log entry; %1 is the date, %2 is the text", "%1 %2", QDateTime::currentDateTime().toString("yyyy-MM-ddThh:mm:ss"), text));
+    logText.insert(0, xi18nc("log entry; %1 is the date, %2 is the text", "%1 %2", QDateTime::currentDateTime().toString("yyyy-MM-ddThh:mm:ss"), text));
 
     emit newLog();
 }
@@ -443,34 +462,56 @@ void Guide::setDECSwap(bool enable)
     if (ST4Driver == NULL || guider == NULL)
         return;
 
-    guider->set_dec_swap(enable);
+    guider->setDECSwap(enable);
     ST4Driver->setDECSwap(enable);
 
 }
 
-bool Guide::do_pulse( GuideDirection ra_dir, int ra_msecs, GuideDirection dec_dir, int dec_msecs )
+bool Guide::sendPulse( GuideDirection ra_dir, int ra_msecs, GuideDirection dec_dir, int dec_msecs )
 {
     if (GuideDriver == NULL || (ra_dir == NO_DIR && dec_dir == NO_DIR))
         return false;
 
-    if (calibration->is_calibrating())
+    if (calibration->isCalibrating())
         QTimer::singleShot( (ra_msecs > dec_msecs ? ra_msecs : dec_msecs) + 100, this, SLOT(capture()));
 
     return GuideDriver->doPulse(ra_dir, ra_msecs, dec_dir, dec_msecs);
 }
 
-bool Guide::do_pulse( GuideDirection dir, int msecs )
+bool Guide::sendPulse( GuideDirection dir, int msecs )
 {
     if (GuideDriver == NULL || dir==NO_DIR)
         return false;
 
-    if (calibration->is_calibrating())
+    if (calibration->isCalibrating())
         QTimer::singleShot(msecs+100, this, SLOT(capture()));
 
     return GuideDriver->doPulse(dir, msecs);
 
 }
 
+QStringList Guide::getST4Devices()
+{
+    QStringList devices;
+
+    foreach(ISD::ST4* driver, ST4List)
+        devices << driver->getDeviceName();
+
+    return devices;
+}
+
+bool Guide::setST4(QString device)
+{
+    for (int i=0; i < ST4List.count(); i++)
+        if (ST4List.at(i)->getDeviceName() == device)
+        {
+            ST4Combo->setCurrentIndex(i);
+            return true;
+        }
+
+    return false;
+}
+
 void Guide::newST4(int index)
 {
     if (ST4List.empty() || index >= ST4List.count())
@@ -489,8 +530,8 @@ double Guide::getReticleAngle()
 void Guide::viewerClosed()
 {
     pmath->set_image(NULL);
-    guider->set_image(NULL);
-    calibration->set_image(NULL);
+    guider->setImage(NULL);
+    calibration->setImage(NULL);
 }
 
 void Guide::processRapidStarData(ISD::CCDChip *targetChip, double dx, double dy, double fit)
@@ -498,7 +539,7 @@ void Guide::processRapidStarData(ISD::CCDChip *targetChip, double dx, double dy,
     // Check if guide star is lost
     if (dx == -1 && dy == -1 && fit == -1)
     {
-        KMessageBox::error(NULL, i18n("Lost track of the guide star. Rapid guide aborted."));
+        KMessageBox::error(NULL, xi18n("Lost track of the guide star. Rapid guide aborted."));
         guider->abort();
         return;
     }
@@ -508,14 +549,14 @@ void Guide::processRapidStarData(ISD::CCDChip *targetChip, double dx, double dy,
     if (targetImage == NULL)
     {
         pmath->set_image(NULL);
-        guider->set_image(NULL);
-        calibration->set_image(NULL);
+        guider->setImage(NULL);
+        calibration->setImage(NULL);
     }
 
     if (rapidGuideReticleSet == false)
     {
         // Let's set reticle parameter on first capture to those of the star, then we check if there
-        // is any deviation
+        // is any set
         double x,y,angle;
         pmath->get_reticle_params(&x, &y, &angle);
         pmath->set_reticle_params(dx, dy, angle);
@@ -524,12 +565,12 @@ void Guide::processRapidStarData(ISD::CCDChip *targetChip, double dx, double dy,
 
     pmath->setRapidStarData(dx, dy);
 
-    if (guider->is_dithering())
+    if (guider->isDithering())
     {
         pmath->do_processing();
         if (guider->dither() == false)
         {
-            appendLogText(i18n("Dithering failed. Autoguiding aborted."));
+            appendLogText(xi18n("Dithering failed. Autoguiding aborted."));
             guider->abort();
             emit ditherFailed();
         }
@@ -548,7 +589,7 @@ void Guide::startRapidGuide()
 
     if (currentCCD->setRapidGuide(targetChip, true) == false)
     {
-        appendLogText(i18n("The CCD does not support Rapid Guiding. Aborting..."));
+        appendLogText(xi18n("The CCD does not support Rapid Guiding. Aborting..."));
         guider->abort();
         return;
     }
@@ -580,45 +621,78 @@ void Guide::stopRapidGuide()
 
 void Guide::dither()
 {
-   if (guider->is_dithering() == false)
+   if (guider->isDithering() == false)
         guider->dither();
 }
 
 void Guide::updateGuideDriver(double delta_ra, double delta_dec)
 {
-    if (guider->is_guiding() == false)
+    guideDeviationRA  = delta_ra;
+    guideDeviationDEC = delta_dec;
+
+    if (guider->isGuiding() == false)
         return;
 
-    if (guider->is_dithering())
+    if (guider->isDithering())
     {
         GuideDriver = ST4Driver;
         return;
     }
 
     // Guide via AO only if guiding deviation is below AO limit
-    if (AODriver != NULL && (fabs(delta_ra) < guider->get_ao_limit()) && (fabs(delta_dec) < guider->get_ao_limit()))
+    if (AODriver != NULL && (fabs(delta_ra) < guider->getAOLimit()) && (fabs(delta_dec) < guider->getAOLimit()))
     {
         if (AODriver != GuideDriver)
-                appendLogText(i18n("Using %1 to correct for guiding errors.", AODriver->getDeviceName()));
+                appendLogText(xi18n("Using %1 to correct for guiding errors.", AODriver->getDeviceName()));
         GuideDriver = AODriver;
         return;
     }
 
     if (GuideDriver != ST4Driver)
-        appendLogText(i18n("Using %1 to correct for guiding errors.", ST4Driver->getDeviceName()));
+        appendLogText(xi18n("Using %1 to correct for guiding errors.", ST4Driver->getDeviceName()));
 
     GuideDriver = ST4Driver;
 }
 
-void Guide::stopGuiding()
+bool Guide::isCalibrationComplete()
+{
+    return calibration->isCalibrationComplete();
+}
+
+bool Guide::isCalibrationSuccessful()
+{
+    return calibration->isCalibrationSuccessful();
+}
+
+bool Guide::startCalibration()
+{
+    return calibration->startCalibration();
+}
+
+bool Guide::stopCalibration()
+{
+    return calibration->stopCalibration();
+}
+
+bool Guide::isGuiding()
+{
+    return guider->isGuiding();
+}
+
+bool Guide::startGuiding()
+{
+    return guider->start();
+}
+
+bool Guide::stopGuiding()
 {
     isSuspended=false;
-    guider->abort(true);
+    return guider->abort(true);
 }
 
 void Guide::setSuspended(bool enable)
 {
-    if (enable == isSuspended || (enable && guider->is_guiding() == false))
+    if (enable == isSuspended || (enable && guider->isGuiding() == false))
         return;
 
     isSuspended = enable;
@@ -627,12 +701,77 @@ void Guide::setSuspended(bool enable)
         capture();
 
     if (isSuspended)
-        appendLogText(i18n("Guiding suspended."));
+        appendLogText(xi18n("Guiding suspended."));
     else
-        appendLogText(i18n("Guiding resumed."));
+        appendLogText(xi18n("Guiding resumed."));
+}
+
+void Guide::setExposure(double value)
+{
+    exposureIN->setValue(value);
 }
 
 
+void Guide::setImageFilter(const QString & value)
+{
+    for (int i=0; i < filterCombo->count(); i++)
+        if (filterCombo->itemText(i) == value)
+        {
+            filterCombo->setCurrentIndex(i);
+            break;
+        }
 }
 
-#include "guide.moc"
+void Guide::setCalibrationOptions(bool useTwoAxis, bool autoCalibration, bool useDarkFrame)
+{
+    calibration->setCalibrationOptions(useTwoAxis, autoCalibration, useDarkFrame);
+}
+
+void Guide::setCalibrationParams(int boxSize, int pulseDuration)
+{
+    calibration->setCalibrationParams(boxSize, pulseDuration);
+}
+
+void Guide::setGuideOptions(int boxSize, const QString & algorithm, bool useSubFrame, bool useRapidGuide)
+{
+     guider->setGuideOptions(boxSize, algorithm, useSubFrame, useRapidGuide);
+}
+
+void Guide::setDither(bool enable, double value)
+{
+    guider->setDither(enable, value);
+}
+
+QList<double> Guide::getGuidingDeviation()
+{
+    QList<double> deviation;
+
+    deviation << guideDeviationRA << guideDeviationDEC;
+
+    return deviation;
+}
+
+void Guide::startAutoCalibrateGuiding()
+{
+    connect(calibration, SIGNAL(calibrationCompleted(bool)), this, SLOT(checkAutoCalibrateGuiding(bool)));
+    calibration->startCalibration();
+}
+
+void Guide::checkAutoCalibrateGuiding(bool successful)
+{
+    calibration->disconnect(this);
+
+    if (successful)
+    {
+        appendLogText(xi18n("Auto calibration successful. Starting guiding..."));
+        startGuiding();
+    }
+    else
+    {
+        appendLogText(xi18n("Auto calibration failed."));
+    }
+}
+
+}
+
+
