@@ -17,10 +17,12 @@
 #include <assert.h>
 
 #include <KMessageBox>
+#include <KLocalizedString>
 
 #include "gmath.h"
 #include "vect.h"
 
+#include "ksnotify.h"
 #include "../guide.h"
 #include "../fitsviewer/fitsviewer.h"
 #include "../fitsviewer/fitsview.h"
@@ -35,6 +37,10 @@
 #define MIN(a, b)  (((a) < (b)) ? (a) : (b))
 #define MAX(a, b)  (((a) > (b)) ? (a) : (b))
 
+#define MAX_GUIDE_STARS 10
+
+//#define GUIDE_LOG
+
 rcalibration::rcalibration(Ekos::Guide *parent)
     : QWidget(parent)
 {
@@ -42,7 +48,7 @@ rcalibration::rcalibration(Ekos::Guide *parent)
 
 	ui.setupUi(this);
 
-    setWindowTitle(i18n("Calibration"));
+    setWindowTitle(xi18n("Calibration"));
 
 	pmath = NULL;
 
@@ -74,15 +80,16 @@ rcalibration::rcalibration(Ekos::Guide *parent)
 	connect( ui.spinBox_ReticleY, 		SIGNAL(valueChanged(double)),	this, SLOT(onReticleYChanged(double)) );
 	connect( ui.spinBox_ReticleAngle,	SIGNAL(valueChanged(double)),	this, SLOT(onReticleAngChanged(double)) );
     connect( ui.pushButton_StartCalibration, SIGNAL(clicked()), 		this, SLOT(onStartReticleCalibrationButtonClick()) );
-	connect( ui.checkBox_AutoMode, 		SIGNAL(stateChanged(int)), 		this, SLOT(onEnableAutoMode(int)) );
-    connect (ui.checkBox_DarkFrame, SIGNAL(toggled(bool)), pmain_wnd, SLOT(setUseDarkFrame(bool)));
+    connect( ui.autoModeCheck, 		SIGNAL(stateChanged(int)), 		this, SLOT(onEnableAutoMode(int)) );
+    connect (ui.darkFrameCheck, SIGNAL(toggled(bool)), pmain_wnd, SLOT(setUseDarkFrame(bool)));
     connect( ui.captureB, SIGNAL(clicked()), this, SLOT(capture()));
 
-    ui.checkBox_DarkFrame->setChecked(Options::useDarkFrame());
-    ui.checkBox_AutoMode->setChecked( Options::useAutoMode() );
+    ui.darkFrameCheck->setChecked(Options::useDarkFrame());
+    ui.autoModeCheck->setChecked( Options::useAutoMode() );
     ui.spinBox_Pulse->setValue( Options::calibrationPulseDuration());
-    ui.checkBox_TwoAxis->setChecked( Options::useTwoAxis());
+    ui.twoAxisCheck->setChecked( Options::useTwoAxis());
     ui.spinBox_DriftTime->setValue( Options::autoModeIterations() );
+    ui.autoCalibrationCheck->setChecked(Options::autoCalibration());
 
 
     idleColor.setRgb(200,200,200);
@@ -90,7 +97,7 @@ rcalibration::rcalibration(Ekos::Guide *parent)
     busyColor = Qt::yellow;
     alertColor = Qt::red;
 
-    fill_interface();
+    fillInterface();
 }
 
 
@@ -99,7 +106,7 @@ rcalibration::~rcalibration()
 
 }
 
-void rcalibration::fill_interface( void )
+void rcalibration::fillInterface( void )
 {
  double rx, ry, rang;
 
@@ -114,7 +121,7 @@ void rcalibration::fill_interface( void )
  	ui.spinBox_ReticleAngle->setValue( rang );
  	ui.progressBar->setValue( 0 );
 
-    if (is_calibrating() && ui.checkBox_AutoMode->isChecked())
+    if (isCalibrating() && ui.autoModeCheck->isChecked())
         ui.progressBar->setVisible(true);
     else
         ui.progressBar->setVisible(false);
@@ -122,7 +129,7 @@ void rcalibration::fill_interface( void )
 }
 
 
-bool rcalibration::set_video_params( int vid_wd, int vid_ht )
+bool rcalibration::setVideoParams( int vid_wd, int vid_ht )
 {
 	if( vid_wd <= 0 || vid_ht <= 0 )
 		return false;
@@ -143,7 +150,7 @@ void rcalibration::update_reticle_pos( double x, double y )
 	ui.spinBox_ReticleY->setValue( y );
 }
 
-void rcalibration::set_math( cgmath *math )
+void rcalibration::setMathObject( cgmath *math )
 {
 	assert( math );
 	pmath = math;
@@ -210,17 +217,45 @@ void rcalibration::onReticleAngChanged( double val )
 
 
 void rcalibration::onStartReticleCalibrationButtonClick()
-{
-
-    if (!pmath)
-        return;
-
+{    
     if (calibrationStage > CAL_START)
     {
-        reset();
+        stopCalibration();
         return;
     }
 
+    startCalibration();
+
+}
+
+bool rcalibration::stopCalibration()
+{
+    if (!pmath)
+        return false;
+
+    calibrationStage = CAL_FINISH;
+    reset();
+
+    return true;
+}
+
+bool rcalibration::startCalibration()
+{
+    if (!pmath)
+        return false;
+
+    if (pmain_wnd->isGuiding())
+    {
+        pmain_wnd->appendLogText(xi18n("Cannot calibrate while autoguiding is active."));
+        return false;
+    }
+
+    if (calibrationStage != CAL_START && ui.autoCalibrationCheck->isChecked())
+    {
+        capture();
+        return true;
+    }
+
     bool ccdInfo=true, scopeInfo=true;
     QString errMsg;
     double ccd_w, ccd_h, g_aperture, g_focal;
@@ -244,41 +279,50 @@ void rcalibration::onStartReticleCalibrationButtonClick()
 
     if (ccdInfo == false || scopeInfo == false)
     {
-            KMessageBox::error(this, i18n("%1 info are missing. Please set the values in INDI Control Panel.", errMsg));
-            return;
+            KMessageBox::error(this, xi18n("%1 info are missing. Please set the values in INDI Control Panel.", errMsg));
+            return false;
     }
 
     if (pmath->get_image())
         disconnect(pmath->get_image(), SIGNAL(guideStarSelected(int,int)), this, SLOT(guideStarSelected(int, int)));
 
+    ui.captureLED->setColor(okColor);
+    ui.selectStarLED->setColor(okColor);
     calibrationStage = CAL_START;
 
+    // Must reset dec swap before we run any calibration procedure!
+    pmain_wnd->setDECSwap(false);
+    pmath->set_dec_swap(false);
+
     pmath->set_lost_star(false);
     pmain_wnd->capture();
 
     Options::setCalibrationPulseDuration(ui.spinBox_Pulse->value());
-    Options::setUseAutoMode(ui.checkBox_AutoMode->isChecked());
-    Options::setUseTwoAxis(ui.checkBox_TwoAxis->isChecked());
-    Options::setUseDarkFrame(ui.checkBox_DarkFrame->isChecked());
+    Options::setUseAutoMode(ui.autoModeCheck->isChecked());
+    Options::setUseTwoAxis(ui.twoAxisCheck->isChecked());
+    Options::setUseDarkFrame(ui.darkFrameCheck->isChecked());
     Options::setAutoModeIterations(ui.spinBox_DriftTime->value());
+    Options::setAutoCalibration(ui.autoCalibrationCheck->isChecked());
 
 	// manual
-	if( ui.checkBox_AutoMode->checkState() != Qt::Checked )
+    if( ui.autoModeCheck->checkState() != Qt::Checked )
 	{
-		calibrate_reticle_manual();
-		return;
+        calibrateManualReticle();
+        return true;
 	}
 
     ui.progressBar->setVisible(true);
 
 	// automatic
-	if( ui.checkBox_TwoAxis->checkState() == Qt::Checked )
-        calibrate_reticle_by_ra_dec(false);
+    if( ui.twoAxisCheck->checkState() == Qt::Checked )
+        calibrateRADECRecticle(false);
 	else
-        calibrate_reticle_by_ra_dec(true);
+        calibrateRADECRecticle(true);
+
+    return true;
 }
 
-void rcalibration::process_calibration()
+void rcalibration::processCalibration()
 {
     if (pmath->get_image())
         pmath->get_image()->setGuideBoxSize(pmath->get_square_size());
@@ -287,7 +331,7 @@ void rcalibration::process_calibration()
     {
         calibrationStage = CAL_ERROR;
         ui.startCalibrationLED->setColor(alertColor);
-        KMessageBox::error(NULL, i18n("Lost track of the guide star. Try increasing the square size or reducing pulse duration."));
+        KMessageBox::error(NULL, xi18n("Lost track of the guide star. Try increasing the square size or reducing pulse duration."));
         reset();
         return;
     }
@@ -298,20 +342,20 @@ void rcalibration::process_calibration()
         break;
 
         case CAL_MANUAL:
-            calibrate_reticle_manual();
+            calibrateManualReticle();
             break;
 
         case CAL_RA_AUTO:
-            calibrate_reticle_by_ra_dec(true);
+            calibrateRADECRecticle(true);
             break;
 
         case CAL_RA_DEC_AUTO:
-            calibrate_reticle_by_ra_dec(false);
+            calibrateRADECRecticle(false);
             break;
     }
 }
 
-bool rcalibration::is_calibrating()
+bool rcalibration::isCalibrating()
 {
     if (calibrationStage >= CAL_START)
         return true;
@@ -322,15 +366,13 @@ bool rcalibration::is_calibrating()
 void rcalibration::reset()
 {
     is_started = false;
-    ui.pushButton_StartCalibration->setText( i18n("Start") );
+    ui.pushButton_StartCalibration->setText( xi18n("Start") );
     ui.startCalibrationLED->setColor(idleColor);
-    calibrationStage = CAL_FINISH;
     ui.progressBar->setVisible(false);
     connect(pmath->get_image(), SIGNAL(guideStarSelected(int,int)), this, SLOT(guideStarSelected(int, int)));
-
 }
 
-void rcalibration::calibrate_reticle_manual( void )
+void rcalibration::calibrateManualReticle( void )
 {
 	//----- manual mode ----
 	// get start point
@@ -339,15 +381,15 @@ void rcalibration::calibrate_reticle_manual( void )
 
 	if( !is_started )
 	{
-		if( ui.checkBox_TwoAxis->checkState() == Qt::Checked )
+        if( ui.twoAxisCheck->checkState() == Qt::Checked )
 		{
-            ui.pushButton_StartCalibration->setText( i18n("Stop GUIDE_RA") );
+            ui.pushButton_StartCalibration->setText( xi18n("Stop GUIDE_RA") );
 		}
 		else
 		{
-            ui.pushButton_StartCalibration->setText( i18n("Stop") );
+            ui.pushButton_StartCalibration->setText( xi18n("Stop") );
 		}
-        pmain_wnd->appendLogText(i18n("Drift scope in RA. Press stop when done."));
+        pmain_wnd->appendLogText(xi18n("Drift scope in RA. Press stop when done."));
 
 		pmath->get_star_screen_pos( &start_x1, &start_y1 );
 		
@@ -356,7 +398,7 @@ void rcalibration::calibrate_reticle_manual( void )
 	}
 	else	// get end point and calc orientation
 	{
-		if( ui.checkBox_TwoAxis->checkState() == Qt::Checked )
+        if( ui.twoAxisCheck->checkState() == Qt::Checked )
 		{
             if( axis == GUIDE_RA )
 			{
@@ -367,8 +409,8 @@ void rcalibration::calibrate_reticle_manual( void )
 				
                 axis = GUIDE_DEC;
 				
-                ui.pushButton_StartCalibration->setText( i18n("Stop GUIDE_DEC") );
-                pmain_wnd->appendLogText(i18n("Drift scope in DEC. Press Stop when done."));
+                ui.pushButton_StartCalibration->setText( xi18n("Stop GUIDE_DEC") );
+                pmain_wnd->appendLogText(xi18n("Drift scope in DEC. Press Stop when done."));
 				return;
 			}
 			else
@@ -378,23 +420,25 @@ void rcalibration::calibrate_reticle_manual( void )
 				// calc orientation
                 if( pmath->calc_and_set_reticle2( start_x1, start_y1, end_x1, end_y1, start_x2, start_y2, end_x2, end_y2, &dec_swap ) )
 				{
-					fill_interface();
+                    fillInterface();
                     if (dec_swap)
-                        pmain_wnd->appendLogText(i18n("DEC swap enabled."));
+                        pmain_wnd->appendLogText(xi18n("DEC swap enabled."));
                     else
-                        pmain_wnd->appendLogText(i18n("DEC swap disabled."));
+                        pmain_wnd->appendLogText(xi18n("DEC swap disabled."));
 
-                    pmain_wnd->appendLogText(i18n("Calibration completed."));
+                    pmain_wnd->appendLogText(xi18n("Calibration completed."));
                     if (Options::playGuideAlarm())
-                            KStars::Instance()->ekosManager()->playOk();
+                            KSNotify::play(KSNotify::NOTIFY_OK);
                     calibrationStage = CAL_FINISH;
+                    emit calibrationCompleted(true);
 
                    pmain_wnd->setDECSwap(dec_swap);
 				}
 				else
 				{
-                    QMessageBox::warning( this, i18n("Error"), i18n("Calibration rejected. Start drift is too short."), QMessageBox::Ok );
+                    QMessageBox::warning( this, xi18n("Error"), xi18n("Calibration rejected. Start drift is too short."), QMessageBox::Ok );
                     calibrationStage = CAL_ERROR;
+                    emit calibrationCompleted(false);
 				}
 			}
 		}
@@ -405,17 +449,19 @@ void rcalibration::calibrate_reticle_manual( void )
 			if( pmath->calc_and_set_reticle( start_x1, start_y1, end_x1, end_y1 ) )
 			{
                 calibrationStage = CAL_FINISH;
-				fill_interface();
-                pmain_wnd->appendLogText(i18n("Calibration completed."));
+                fillInterface();
+                pmain_wnd->appendLogText(xi18n("Calibration completed."));
+                emit calibrationCompleted(true);
                 if (Options::playGuideAlarm())
-                        KStars::Instance()->ekosManager()->playOk();
+                        KSNotify::play(KSNotify::NOTIFY_OK);
 			}
 			else
 			{
                 calibrationStage = CAL_ERROR;
-                QMessageBox::warning( this, i18n("Error"), i18n("Calibration rejected. Start drift is too short."), QMessageBox::Ok );
+                emit calibrationCompleted(false);
+                QMessageBox::warning( this, xi18n("Error"), xi18n("Calibration rejected. Start drift is too short."), QMessageBox::Ok );
                 if (Options::playGuideAlarm())
-                        KStars::Instance()->ekosManager()->playError();
+                        KSNotify::play(KSNotify::NOTIFY_ERROR);
 			}
 		}
 
@@ -424,7 +470,7 @@ void rcalibration::calibrate_reticle_manual( void )
 	}
 }
 
-void rcalibration::calibrate_reticle_by_ra_dec( bool ra_only )
+void rcalibration::calibrateRADECRecticle( bool ra_only )
 {
  bool auto_term_ok = false;
 
@@ -457,9 +503,9 @@ void rcalibration::calibrate_reticle_by_ra_dec( bool ra_only )
 
             ui.progressBar->setValue( 0 );
 
-            ui.pushButton_StartCalibration->setText(i18n("Abort"));
+            ui.pushButton_StartCalibration->setText(xi18n("Abort"));
 
-            pmain_wnd->appendLogText(i18n("GUIDE_RA Drifting..."));
+            pmain_wnd->appendLogText(xi18n("GUIDE_RA Drifting..."));
 
             // get start point
             //pmath->get_star_screen_pos( &start_x1, &start_y1 );
@@ -469,7 +515,7 @@ void rcalibration::calibrate_reticle_by_ra_dec( bool ra_only )
 
             //qDebug() << "Start X1 " << start_x1 << " Start Y1 " << start_y1 << endl;
 
-            pmain_wnd->do_pulse( RA_INC_DIR, pulseDuration );
+            pmain_wnd->sendPulse( RA_INC_DIR, pulseDuration );
 
             iterations++;
 
@@ -482,11 +528,13 @@ void rcalibration::calibrate_reticle_by_ra_dec( bool ra_only )
             break;
 
         case CAL_RA_INC:
-            pmain_wnd->do_pulse( RA_INC_DIR, pulseDuration );
+            pmain_wnd->sendPulse( RA_INC_DIR, pulseDuration );
             iterations++;
             ui.progressBar->setValue( iterations );
 
-            //qDebug() << "Iteration " << iterations << " and auto drift time is " << auto_drift_time << endl;
+            #ifdef GUIDE_LOG
+            qDebug() << "Iteration " << iterations << " and auto drift time is " << auto_drift_time << endl;
+            #endif
 
             if (iterations == auto_drift_time)
                 calibrationStage = CAL_RA_DEC;
@@ -498,12 +546,14 @@ void rcalibration::calibrate_reticle_by_ra_dec( bool ra_only )
             if (iterations == auto_drift_time)
             {
                 pmath->get_star_screen_pos( &end_x1, &end_y1 );
-                //qDebug() << "End X1 " << end_x1 << " End Y1 " << end_y1 << endl;
+                #ifdef GUIDE_LOG
+                qDebug() << "End X1 " << end_x1 << " End Y1 " << end_y1 << endl;
+                #endif
 
                 phi = pmath->calc_phi( start_x1, start_y1, end_x1, end_y1 );
                 ROT_Z = RotateZ( -M_PI*phi/180.0 ); // derotates...
 
-                pmain_wnd->appendLogText(i18n("Running..."));
+                pmain_wnd->appendLogText(xi18n("Running..."));
 
             }
 
@@ -532,7 +582,7 @@ void rcalibration::calibrate_reticle_by_ra_dec( bool ra_only )
         {
             if (iterations < turn_back_time)
             {
-                pmain_wnd->do_pulse( RA_DEC_DIR, pulseDuration );
+                pmain_wnd->sendPulse( RA_DEC_DIR, pulseDuration );
                 iterations++;
 
                 ui.progressBar->setValue( iterations );
@@ -540,9 +590,10 @@ void rcalibration::calibrate_reticle_by_ra_dec( bool ra_only )
             }
 
             calibrationStage = CAL_ERROR;
-            QMessageBox::warning( this, i18n("Warning"), i18np("GUIDE_RA: Scope cannot reach the start point after %1 iteration.\nPossible mount or drive problems...", "GUIDE_RA: Scope cannot reach the start point after %1 iterations.\nPossible mount or drive problems...", turn_back_time), QMessageBox::Ok );
+            emit calibrationCompleted(false);
+            QMessageBox::warning( this, xi18n("Warning"), xi18np("GUIDE_RA: Scope cannot reach the start point after %1 iteration.\nPossible mount or drive problems...", "GUIDE_RA: Scope cannot reach the start point after %1 iterations.\nPossible mount or drive problems...", turn_back_time), QMessageBox::Ok );
             if (Options::playGuideAlarm())
-                    KStars::Instance()->ekosManager()->playError();
+                    KSNotify::play(KSNotify::NOTIFY_ERROR);
             reset();
             break;
         }
@@ -553,32 +604,38 @@ void rcalibration::calibrate_reticle_by_ra_dec( bool ra_only )
             start_x2 = cur_x;
             start_y2 = cur_y;
 
-           // qDebug() << "Start X2 " << start_x2 << " start Y2 " << start_y2 << endl;
+           #ifdef GUIDE_LOG
+           qDebug() << "Start X2 " << start_x2 << " start Y2 " << start_y2 << endl;
+           #endif
 
-            pmain_wnd->do_pulse( DEC_INC_DIR, pulseDuration );
+            pmain_wnd->sendPulse( DEC_INC_DIR, pulseDuration );
             iterations++;
             dec_iterations = 1;
             ui.progressBar->setValue( iterations );
-            pmain_wnd->appendLogText(i18n("GUIDE_DEC drifting..."));
+            pmain_wnd->appendLogText(xi18n("GUIDE_DEC drifting..."));
             break;
         }
         // calc orientation
         if( pmath->calc_and_set_reticle( start_x1, start_y1, end_x1, end_y1, totalPulse) )
         {
             calibrationStage = CAL_FINISH;
-            fill_interface();
-            pmain_wnd->appendLogText(i18n("Calibration completed."));
+            fillInterface();
+            pmain_wnd->appendLogText(xi18n("Calibration completed."));
+            emit calibrationCompleted(true);
             ui.startCalibrationLED->setColor(okColor);
             if (Options::playGuideAlarm())
-                    KStars::Instance()->ekosManager()->playError();
+                    KSNotify::play(KSNotify::NOTIFY_ERROR);
+            if (ui.autoCalibrationCheck->isChecked())
+                selectAutoStar(pmath->get_image());
         }
         else
         {
-            QMessageBox::warning( this, i18n("Error"), i18n("Calibration rejected. Star drift is too short."), QMessageBox::Ok );
-            ui.startCalibrationLED->setColor(alertColor);
+            QMessageBox::warning( this, xi18n("Error"), xi18n("Calibration rejected. Star drift is too short."), QMessageBox::Ok );
+            ui.startCalibrationLED->setColor(alertColor);            
             calibrationStage = CAL_ERROR;
+            emit calibrationCompleted(false);
             if (Options::playGuideAlarm())
-                    KStars::Instance()->ekosManager()->playError();
+                    KSNotify::play(KSNotify::NOTIFY_ERROR);
         }
 
         reset();
@@ -586,12 +643,14 @@ void rcalibration::calibrate_reticle_by_ra_dec( bool ra_only )
         }
 
     case CAL_DEC_INC:
-        pmain_wnd->do_pulse( DEC_INC_DIR, pulseDuration );
+        pmain_wnd->sendPulse( DEC_INC_DIR, pulseDuration );
         iterations++;
         dec_iterations++;
         ui.progressBar->setValue( iterations );
 
-        //qDebug() << "Iteration " << iterations << " and auto drift time is " << auto_drift_time << endl;
+        #ifdef GUIDE_LOG
+        qDebug() << "Iteration " << iterations << " and auto drift time is " << auto_drift_time << endl;
+        #endif
 
         if (dec_iterations == auto_drift_time)
             calibrationStage = CAL_DEC_DEC;
@@ -603,19 +662,21 @@ void rcalibration::calibrate_reticle_by_ra_dec( bool ra_only )
         if (dec_iterations == auto_drift_time)
         {
             pmath->get_star_screen_pos( &end_x2, &end_y2 );
-            //qDebug() << "End X2 " << end_x2 << " End Y2 " << end_y2 << endl;
+            #ifdef GUIDE_LOG
+            qDebug() << "End X2 " << end_x2 << " End Y2 " << end_y2 << endl;
+            #endif
 
             phi = pmath->calc_phi( start_x2, start_y2, end_x2, end_y2 );
             ROT_Z = RotateZ( -M_PI*phi/180.0 ); // derotates...
 
-            pmain_wnd->appendLogText(i18n("Running..."));
+            pmain_wnd->appendLogText(xi18n("Running..."));
         }
 
         //----- Z-check (new!) -----
         double cur_x, cur_y;
         pmath->get_star_screen_pos( &cur_x, &cur_y );
 
-        //pmain_wnd->appendLogText(i18n("GUIDE_DEC running back...");
+        //pmain_wnd->appendLogText(xi18n("GUIDE_DEC running back...");
 
         //qDebug() << "Cur X1 " << cur_x << " Cur Y1 " << cur_y << endl;
 
@@ -638,7 +699,7 @@ void rcalibration::calibrate_reticle_by_ra_dec( bool ra_only )
     {
         if (iterations < turn_back_time)
         {
-            pmain_wnd->do_pulse( DEC_DEC_DIR, pulseDuration );
+            pmain_wnd->sendPulse( DEC_DEC_DIR, pulseDuration );
             iterations++;
             dec_iterations++;
 
@@ -647,9 +708,10 @@ void rcalibration::calibrate_reticle_by_ra_dec( bool ra_only )
         }
 
         calibrationStage = CAL_ERROR;
-        QMessageBox::warning( this, i18n("Warning"), i18np("GUIDE_DEC: Scope cannot reach the start point after %1 iteration.\nPossible mount or drive problems...", "GUIDE_DEC: Scope cannot reach the start point after %1 iterations.\nPossible mount or drive problems...", turn_back_time), QMessageBox::Ok );
+        emit calibrationCompleted(false);
+        QMessageBox::warning( this, xi18n("Warning"), xi18np("GUIDE_DEC: Scope cannot reach the start point after %1 iteration.\nPossible mount or drive problems...", "GUIDE_DEC: Scope cannot reach the start point after %1 iterations.\nPossible mount or drive problems...", turn_back_time), QMessageBox::Ok );
         if (Options::playGuideAlarm())
-                KStars::Instance()->ekosManager()->playError();
+                KSNotify::play(KSNotify::NOTIFY_ERROR);
         reset();
         break;
     }
@@ -659,25 +721,29 @@ void rcalibration::calibrate_reticle_by_ra_dec( bool ra_only )
     if( pmath->calc_and_set_reticle2( start_x1, start_y1, end_x1, end_y1, start_x2, start_y2, end_x2, end_y2, &swap_dec, totalPulse ) )
     {
         calibrationStage = CAL_FINISH;
-        fill_interface();
+        fillInterface();
         if (swap_dec)
-            pmain_wnd->appendLogText(i18n("DEC swap enabled."));
+            pmain_wnd->appendLogText(xi18n("DEC swap enabled."));
         else
-            pmain_wnd->appendLogText(i18n("DEC swap disabled."));
-        pmain_wnd->appendLogText(i18n("Calibration completed."));        
+            pmain_wnd->appendLogText(xi18n("DEC swap disabled."));
+        pmain_wnd->appendLogText(xi18n("Calibration completed."));
+        emit calibrationCompleted(true);
         ui.startCalibrationLED->setColor(okColor);
         pmain_wnd->setDECSwap(swap_dec);
         if (Options::playGuideAlarm())
-                KStars::Instance()->ekosManager()->playOk();
+                KSNotify::play(KSNotify::NOTIFY_OK);
+        if (ui.autoCalibrationCheck->isChecked())
+            selectAutoStar(pmath->get_image());
 
     }
     else
     {
-        QMessageBox::warning( this, i18n("Error"), i18n("Calibration rejected. Star drift is too short."), QMessageBox::Ok );
+        QMessageBox::warning( this, xi18n("Error"), xi18n("Calibration rejected. Star drift is too short."), QMessageBox::Ok );
+        emit calibrationCompleted(false);
         ui.startCalibrationLED->setColor(alertColor);
         calibrationStage = CAL_ERROR;
         if (Options::playGuideAlarm())
-                KStars::Instance()->ekosManager()->playError();
+                KSNotify::play(KSNotify::NOTIFY_ERROR);
     }
 
     reset();
@@ -710,16 +776,22 @@ void rcalibration::guideStarSelected(int x, int y)
     calibrationStage = CAL_START;
 
     ui.pushButton_StartCalibration->setEnabled(true);
+
+    if (ui.autoCalibrationCheck->isChecked())
+        startCalibration();
 }
 
 void rcalibration::capture()
 {
+    if (isCalibrating())
+        stopCalibration();
+
     calibrationStage = CAL_CAPTURE_IMAGE;
 
     if (pmain_wnd->capture())
     {
          ui.captureLED->setColor(busyColor);
-         pmain_wnd->appendLogText(i18n("Capturing image..."));
+         pmain_wnd->appendLogText(xi18n("Capturing image..."));
     }
     else
     {
@@ -728,7 +800,7 @@ void rcalibration::capture()
     }
 }
 
-void rcalibration::set_image(FITSView *image)
+void rcalibration::setImage(FITSView *image)
 {
 
     if (image == NULL)
@@ -740,19 +812,22 @@ void rcalibration::set_image(FITSView *image)
         case CAL_SELECT_STAR:
           {
             pmath->resize_square(pmath->get_square_index());
-            pmain_wnd->appendLogText(i18n("Image captured..."));
+            pmain_wnd->appendLogText(xi18n("Image captured..."));
 
             ui.captureLED->setColor(okColor);
             calibrationStage = CAL_SELECT_STAR;
             ui.selectStarLED->setColor(busyColor);
 
-            FITSImage *image_data = image->getImageData();
+            FITSData *image_data = image->getImageData();
 
-            set_video_params(image_data->getWidth(), image_data->getHeight());
+            setVideoParams(image_data->getWidth(), image_data->getHeight());
 
-            select_auto_star(image);
+            QPair<double,double> star = selectAutoStar(image);
 
-            connect(image, SIGNAL(guideStarSelected(int,int)), this, SLOT(guideStarSelected(int, int)));
+            if (ui.autoCalibrationCheck->isChecked())
+                guideStarSelected(star.first, star.second);
+            else
+                connect(image, SIGNAL(guideStarSelected(int,int)), this, SLOT(guideStarSelected(int, int)));
 
          }
             break;
@@ -762,21 +837,95 @@ void rcalibration::set_image(FITSView *image)
     }
 }
 
-void rcalibration::select_auto_star(FITSView *image)
+bool brighterThan(Edge *s1, Edge *s2)
 {
-    int maxVal=-1;
-    Edge *guideStar = NULL;
+    return s1->width > s2->width;
+}
 
-    FITSImage *image_data = image->getImageData();
+QPair<double,double> rcalibration::selectAutoStar(FITSView *image)
+{
+    //int maxVal=-1;
+    //Edge *guideStar = NULL;
+    QPair<double,double> star;
+
+    FITSData *image_data = image->getImageData();
     image_data->findStars();
 
+    QList<Edge*> starCenters = image_data->getStarCenters();
 
-    foreach(Edge *center, image_data->getStarCenters())
+    if (starCenters.empty())
+        return star;
+
+    qSort(starCenters.begin(), starCenters.end(), brighterThan);
+
+    int maxX = image_data->getWidth();
+    int maxY = image_data->getHeight();
+
+    int scores[MAX_GUIDE_STARS];
+
+    int maxIndex = MAX_GUIDE_STARS < starCenters.count() ? MAX_GUIDE_STARS : starCenters.count();
+
+    for (int i=0; i < maxIndex; i++)
+    {
+        int score=100;
+
+        Edge *center = starCenters.at(i);
+
+        //qDebug() << "#" << i << " X: " << center->x << " Y: " << center->y << " HFR: " << center->HFR << " Width" << center->width << endl;
+
+        // Severely reject stars close to edges
+        if (center->x < (center->width*6) || center->y < (center->width*6) || center->x > (maxX-center->width*6) || center->y > (maxY-center->width*6))
+            score-=50;
+
+        // Moderately reject stars close to other stars
+        foreach(Edge *edge, starCenters)
+        {
+            if (edge == center)
+                continue;
+
+            if (abs(center->x - edge->x) < center->width*2 && abs(center->y - edge->y) < center->width*2)
+            {
+                score -= 20;
+                break;
+            }
+        }
+
+        scores[i] = score;
+    }
+
+    int maxScore=0;
+    int maxScoreIndex=0;
+    for (int i=0; i < maxIndex; i++)
+    {
+        if (scores[i] > maxScore)
+        {
+            maxScore = scores[i];
+            maxScoreIndex = i;
+        }
+    }
+
+    star = qMakePair(starCenters[maxScoreIndex]->x, starCenters[maxScoreIndex]->y);
+
+    // Select appropiate square size
+    int idealSize = ceil(starCenters[maxScoreIndex]->width * 1.5);
+
+    for (int i=0; i < ui.comboBox_SquareSize->count(); i++)
+    {
+        if (idealSize < ui.comboBox_SquareSize->itemText(i).toInt())
+        {
+            ui.comboBox_SquareSize->setCurrentIndex(i);
+            pmath->resize_square(i);
+            break;
+        }
+    }
+
+    /*foreach(Edge *center, image_data->getStarCenters())
     {
         if (center->val > maxVal)
         {
             guideStar = center;
             maxVal = center->val;
+            star = qMakePair(guideStar->x, guideStar->y);
 
         }
 
@@ -784,5 +933,27 @@ void rcalibration::select_auto_star(FITSView *image)
 
     if (guideStar != NULL)
         image->setGuideSquare(guideStar->x, guideStar->y);
+    */
+
+    return star;
+}
+
+void rcalibration::setCalibrationOptions(bool useTwoAxis, bool autoCalibration, bool useDarkFrame)
+{
+    ui.twoAxisCheck->setChecked(useTwoAxis);
+    ui.autoCalibrationCheck->setChecked(autoCalibration);
+    ui.darkFrameCheck->setChecked(useDarkFrame);
+}
+
+void rcalibration::setCalibrationParams(int boxSize, int pulseDuration)
+{
+    for (int i=0; i < ui.comboBox_SquareSize->count(); i++)
+        if (ui.comboBox_SquareSize->itemText(i).toInt() == boxSize)
+        {
+            ui.comboBox_SquareSize->setCurrentIndex(i);
+            break;
+        }
+
+    ui.spinBox_Pulse->setValue(pulseDuration);
 }
 
