@@ -1,30 +1,22 @@
+/*  INDI GUI Manager
+    Copyright (C) 2012 Jasem Mutlaq
+
+    This application is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+ */
+
 #ifndef GUIMANAGER_H
 #define GUIMANAGER_H
 
-/*  INDI frontend for KStars
-    Copyright (C) 2012 Jasem Mutlaq
-
-    This application is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
- */
-
-/*  INDI frontend for KStars
-    Copyright (C) 2012 Jasem Mutlaq
-
-    This application is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
- */
-
 #include <QGridLayout>
 #include <QFrame>
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QVBoxLayout>
 #include <QTabWidget>
+#include <QPointer>
 
 #include <indibase.h>
 
@@ -35,14 +27,21 @@ class QHBoxLayout;
 class QVBoxLayout;
 class QFrame;
 class QString;
-class QTextEdit;
 class QTabWidget;
 class QGridLayout;
 class QPushButton;
+class FITSViewer;
 
 class INDI_D;
 
-
+/**
+ * @class GUIManager
+ * GUIManager creates the INDI Control Panel upon receving a new device. Each device is displayed
+ * on a separate tab. The device and property GUI creation is performed dynamically via introspection. As new properties
+ * arrive from the ClientManager, they get created in the GUI.
+ *
+ * @author Jasem Mutlaq
+ */
 class GUIManager : public QWidget
 {
     Q_OBJECT
@@ -62,6 +61,8 @@ public:
 
     int size() { return guidevices.size(); }
 
+    FITSViewer *getGenericFITSViewer();
+
   private:
     /*****************************************************************
     * GUI stuff
@@ -76,6 +77,7 @@ public:
     QList<ClientManager *> clients;
     QList<INDI_D*> guidevices;
 
+    QPointer<FITSViewer> genericViewer;
 
   public slots:
     void clearLog();
