@@ -12,25 +12,28 @@
 #include <string.h>
 
 #include <KMessageBox>
-#include <KStatusBar>
-#include <KTemporaryFile>
+#include <QStatusBar>
+#include <QImageReader>
 
 #include <basedevice.h>
 
-#ifdef HAVE_CFITSIO_H
+#ifdef HAVE_CFITSIO
 #include "fitsviewer/fitsviewer.h"
 #include "fitsviewer/fitscommon.h"
 #include "fitsviewer/fitsview.h"
-#include "fitsviewer/fitsimage.h"
+#include "fitsviewer/fitsdata.h"
 #endif
 
 #include "clientmanager.h"
 #include "streamwg.h"
 #include "indiccd.h"
-#include "kstars.h"
+#include "guimanager.h"
+#include "kstarsdata.h"
 
 #include <ekos/ekosmanager.h>
 
+#include "ksnotify.h"
+#include "imageviewer.h"
 #include "Options.h"
 
 const int MAX_FILENAME_LEN = 1024;
@@ -121,6 +124,59 @@ void CCDChip::setImage(FITSView *image, FITSMode imageType)
 
 }
 
+bool CCDChip::getFrameMinMax(int *minX, int *maxX, int *minY, int *maxY, int *minW, int *maxW, int *minH, int *maxH)
+{
+    INumberVectorProperty *frameProp = NULL;
+
+    switch (type)
+    {
+       case PRIMARY_CCD:
+        frameProp = baseDevice->getNumber("CCD_FRAME");
+        break;
+
+      case GUIDE_CCD:
+        frameProp = baseDevice->getNumber("GUIDER_FRAME");
+        break;
+
+    }
+
+    if (frameProp == NULL)
+        return false;
+
+    INumber *arg = IUFindNumber(frameProp, "X");
+    if (arg == NULL)
+        return false;
+
+    *minX = arg->min;
+    *maxX = arg->max;
+
+
+    arg = IUFindNumber(frameProp, "Y");
+    if (arg == NULL)
+        return false;
+
+    *minY = arg->min;
+    *maxY = arg->max;
+
+    arg = IUFindNumber(frameProp, "WIDTH");
+    if (arg == NULL)
+        return false;
+
+    *minW = arg->min;
+    *maxW = arg->max;
+
+
+    arg = IUFindNumber(frameProp, "HEIGHT");
+    if (arg == NULL)
+        return false;
+
+    *minH = arg->min;
+    *maxH = arg->max;
+
+    return true;
+
+}
+
 bool CCDChip::getFrame(int *x, int *y, int *w, int *h)
 {
 
@@ -357,20 +413,56 @@ void CCDChip::setCanAbort(bool value)
 {
     CanAbort = value;
 }
-FITSImage *CCDChip::getImageData() const
+FITSData *CCDChip::getImageData() const
 {
     return imageData;
 }
 
-void CCDChip::setImageData(FITSImage *value)
+void CCDChip::setImageData(FITSData *value)
 {
     imageData = value;
 }
+int CCDChip::getISOIndex() const
+{
+    ISwitchVectorProperty *isoProp = baseDevice->getSwitch("CCD_ISO");
+    if (isoProp == NULL)
+        return -1;
+
+    return IUFindOnSwitchIndex(isoProp);
+}
+
+bool CCDChip::setISOIndex(int value)
+{
+    ISwitchVectorProperty *isoProp = baseDevice->getSwitch("CCD_ISO");
+    if (isoProp == NULL)
+        return false;
+
+    IUResetSwitch(isoProp);
+    isoProp->sp[value].s = ISS_ON;
+
+    clientManager->sendNewSwitch(isoProp);
+
+    return true;
+}
+
+QStringList CCDChip::getISOList() const
+{
+   QStringList isoList;
+
+   ISwitchVectorProperty *isoProp = baseDevice->getSwitch("CCD_ISO");
+   if (isoProp == NULL)
+       return isoList;
+
+   for (int i=0; i < isoProp->nsp; i++)
+       isoList << isoProp->sp[i].label;
+
+    return isoList;
+}
 
 bool CCDChip::isCapturing()
 {
     INumberVectorProperty *expProp = NULL;
-
+    
     switch (type)
     {
     case PRIMARY_CCD:
@@ -676,6 +768,7 @@ CCD::CCD(GDInterface *iPtr) : DeviceDecorator(iPtr)
     dType = KSTARS_CCD;
     ISOMode   = true;
     HasGuideHead = false;
+    HasCooler    = false;
     fv          = NULL;
     streamWindow      = NULL;
     ST4Driver = NULL;
@@ -690,7 +783,7 @@ CCD::CCD(GDInterface *iPtr) : DeviceDecorator(iPtr)
 
 CCD::~CCD()
 {
-#ifdef HAVE_CFITSIO_H
+#ifdef HAVE_CFITSIO
     delete (fv);
 #endif
     delete (primaryChip);
@@ -709,6 +802,8 @@ void CCD::registerProperty(INDI::Property *prop)
     {
         ISwitchVectorProperty *ccdFrame = prop->getSwitch();
 
+        primaryChip->clearFrameTypes();
+
         for (int i=0; i < ccdFrame->nsp; i++)
             primaryChip->addFrameLabel(ccdFrame->sp[i].label);
     }
@@ -748,6 +843,13 @@ void CCD::registerProperty(INDI::Property *prop)
         if (sp && sp->p != IP_RO)
             guideChip->setCanAbort(true);
     }
+    else if (!strcmp(prop->getName(), "CCD_TEMPERATURE"))
+    {
+        INumberVectorProperty *np = prop->getNumber();
+        HasCooler = true;
+        if (np)
+            emit newTemperatureValue(np->np[0].value);
+    }
 
     DeviceDecorator::registerProperty(prop);
 }
@@ -759,20 +861,6 @@ void CCD::processLight(ILightVectorProperty *lvp)
 
 void CCD::processNumber(INumberVectorProperty *nvp)
 {
-    if (!strcmp(nvp->name, "CCD_FRAME"))
-    {
-        INumber *wd = IUFindNumber(nvp, "WIDTH");
-        INumber *ht = IUFindNumber(nvp, "HEIGHT");
-
-        if (wd && ht && streamWindow)
-            streamWindow->setSize(wd->value, ht->value);
-
-        emit numberUpdated(nvp);
-
-        return;
-
-    }
-
     if (!strcmp(nvp->name, "CCD_EXPOSURE"))
     {
         if (nvp->s == IPS_BUSY)
@@ -781,6 +869,18 @@ void CCD::processNumber(INumberVectorProperty *nvp)
             if (np)
                 emit newExposureValue(primaryChip, np->value);
         }
+
+        return;
+    }
+
+    if (!strcmp(nvp->name, "CCD_TEMPERATURE"))
+    {
+        HasCooler = true;
+        INumber *np = IUFindNumber(nvp, "CCD_TEMPERATURE_VALUE");
+            if (np)
+                emit newTemperatureValue(np->value);
+
+            return;
     }
 
     if (!strcmp(nvp->name, "GUIDER_EXPOSURE"))
@@ -859,7 +959,7 @@ void CCD::processNumber(INumberVectorProperty *nvp)
 
 void CCD::processSwitch(ISwitchVectorProperty *svp)
 {
-    if (!strcmp(svp->name, "VIDEO_STREAM"))
+    if (!strcmp(svp->name, "CCD_VIDEO_STREAM") || !strcmp(svp->name, "VIDEO_STREAM"))
     {
         if (streamWindow == NULL && svp->sp[0].s == ISS_ON)
         {
@@ -869,20 +969,21 @@ void CCD::processSwitch(ISwitchVectorProperty *svp)
             IBLOBVectorProperty *rawBP = baseDevice->getBLOB("CCD1");
             if (rawBP)
             {
-                INumberVectorProperty *ccdFrame = baseDevice->getNumber("CCD_FRAME");
+                int x,y,w,h;
+                int binx, biny;
 
-                if (ccdFrame == NULL)
-                    return;
+                primaryChip->getFrame(&x, &y, &w, &h);
+                primaryChip->getBinning(&binx, &biny);
+                streamW = w / binx;
+                streamH = h / biny;
 
-                INumber *wd = IUFindNumber(ccdFrame, "WIDTH");
-                INumber *ht = IUFindNumber(ccdFrame, "HEIGHT");
+                rawBP->bp[0].aux0 = &(streamW);
+                rawBP->bp[0].aux1 = &(streamH);
 
-                rawBP->bp[0].aux0 = &(wd->value);
-                rawBP->bp[0].aux1 = &(ht->value);
-
-                if (wd && ht)
-                    streamWindow->setSize(wd->value, ht->value);
+                if (streamWindow->getWidth() != streamW || streamWindow->getHeight() != streamH)
+                    streamWindow->setSize(streamW, streamH);
             }
+
         }
 
         streamWindow->disconnect();
@@ -914,8 +1015,6 @@ void CCD::processSwitch(ISwitchVectorProperty *svp)
 
         emit switchUpdated(svp);
 
-        return;
-
     }
 
     DeviceDecorator::processSwitch(svp);
@@ -931,6 +1030,10 @@ void CCD::processText(ITextVectorProperty *tvp)
 void CCD::processBLOB(IBLOB* bp)
 {
 
+    enum blobType { BLOB_IMAGE, BLOB_FITS, BLOB_CR2, BLOB_OTHER} BType;
+
+    BType = BLOB_OTHER;
+
     QString format(bp->format);
 
     // If stream, process it first
@@ -939,13 +1042,33 @@ void CCD::processBLOB(IBLOB* bp)
         if (streamWindow->isStreamEnabled() == false)
             return;
 
+        int x,y,w,h;
+        int binx, biny;
+
+        primaryChip->getFrame(&x, &y, &w, &h);
+        primaryChip->getBinning(&binx, &biny);
+        streamW = w / binx;
+        streamH = h / biny;
+
+        if (streamWindow->getWidth() != streamW || streamWindow->getHeight() != streamH)
+            streamWindow->setSize(streamW, streamH);
+
         streamWindow->show();
         streamWindow->newFrame(bp);
         return;
     }
 
-    // If it's not FITS, don't process it.
-    if (format.contains("fits") == false)
+    QByteArray fmt = QString(bp->format).toLower().remove(".").toUtf8();
+
+    // If it's not FITS or an image, don't process it.
+    if ( (QImageReader::supportedImageFormats().contains(fmt)))
+        BType = BLOB_IMAGE;
+    else if (format.contains("fits"))
+        BType = BLOB_FITS;
+    else if (format.contains("cr2"))
+        BType = BLOB_CR2;
+
+    if (BType == BLOB_OTHER)
     {
         DeviceDecorator::processBLOB(bp);
         return;
@@ -961,19 +1084,19 @@ void CCD::processBLOB(IBLOB* bp)
     QString currentDir;
 
     if (targetChip->isBatchMode() == false)
-        currentDir = "/tmp";
+        currentDir = QStandardPaths::writableLocation(QStandardPaths::TempLocation);
     else
         currentDir  =  fitsDir.isEmpty() ? Options::fitsDir() : fitsDir;
 
     int nr, n=0;
-    KTemporaryFile tmpFile;
+    QTemporaryFile tmpFile(QDir::tempPath() + "/fitsXXXXXX");
 
     if (currentDir.endsWith('/'))
         currentDir.truncate(sizeof(currentDir)-1);
 
     if (QDir(currentDir).exists() == false)
     {
-        KMessageBox::error(0, i18n("FITS directory %1 does not exist. Please update the directory in the options.", currentDir));
+        KMessageBox::error(0, xi18n("FITS directory %1 does not exist. Please update the directory in the options.", currentDir));
         emit BLOBUpdated(NULL);
         return;
     }
@@ -984,7 +1107,7 @@ void CCD::processBLOB(IBLOB* bp)
     if (Options::showFITS() && (targetChip->isBatchMode() == false || targetChip->getCaptureMode() != FITS_NORMAL))
     {
 
-        tmpFile.setPrefix("fits");
+        //tmpFile.setPrefix("fits");
         tmpFile.setAutoRemove(false);
 
          if (!tmpFile.open())
@@ -1010,9 +1133,9 @@ void CCD::processBLOB(IBLOB* bp)
          QString ts = QDateTime::currentDateTime().toString("yyyy-MM-ddThh:mm:ss");
 
          if (ISOMode == false)
-               filename += seqPrefix + (seqPrefix.isEmpty() ? "" : "_") +  QString("%1.fits").arg(QString().sprintf("%02d", seqCount));
+               filename += seqPrefix + (seqPrefix.isEmpty() ? "" : "_") +  QString("%1.%2").arg(QString().sprintf("%02d", seqCount)).arg(QString(fmt));
           else
-               filename += seqPrefix + (seqPrefix.isEmpty() ? "" : "_") + QString("%1_%2.fits").arg(QString().sprintf("%02d", seqCount)).arg(ts);
+               filename += seqPrefix + (seqPrefix.isEmpty() ? "" : "_") + QString("%1_%2.%3").arg(QString().sprintf("%02d", seqCount)).arg(ts).arg(QString(fmt));
 
             QFile fits_temp_file(filename);
             if (!fits_temp_file.open(QIODevice::WriteOnly))
@@ -1030,16 +1153,18 @@ void CCD::processBLOB(IBLOB* bp)
             fits_temp_file.close();
     }
 
-    addFITSKeywords(filename);
+    if (BType == BLOB_FITS)
+        addFITSKeywords(filename);
 
     // store file name
-    strncpy(bp->label, filename.toLatin1(), MAXINDILABEL);
+    strncpy(BLOBFilename, filename.toLatin1(), MAXINDIFILENAME);
+    bp->aux2 = BLOBFilename;
 
     if ((targetChip->isBatchMode() && targetChip->getCaptureMode() == FITS_NORMAL) || Options::showFITS() == false)
-        KStars::Instance()->statusBar()->changeItem( i18n("FITS file saved to %1", filename ), 0);
+        KStars::Instance()->statusBar()->showMessage( xi18n("%1 file saved to %2", QString(fmt).toUpper(), filename ), 0);
 
-    if (Options::playFITSAlarm() && KStars::Instance()->ekosManager())
-        KStars::Instance()->ekosManager()->playFITS();
+    if (Options::playFITSAlarm())
+        KSNotify::play(KSNotify::NOTIFY_FILE_RECEIVED);
 
     if (targetChip->showFITS() == false && targetChip->getCaptureMode() == FITS_NORMAL)
     {
@@ -1047,32 +1172,83 @@ void CCD::processBLOB(IBLOB* bp)
         return;
     }
 
+    if (BType == BLOB_IMAGE || BType == BLOB_CR2)
+    {
+
+
+        if (BType == BLOB_CR2)
+        {
+            if (QStandardPaths::findExecutable("dcraw").isEmpty() == false && QStandardPaths::findExecutable("cjpeg").isEmpty() == false)
+            {
+                QProcess dcraw;
+                QString rawFileName = filename;
+                rawFileName = rawFileName.remove(0, rawFileName.lastIndexOf("/"));
+                QString templateName = QString("%1/%2.XXXXXX").arg(QDir::tempPath()).arg(rawFileName);
+                QTemporaryFile jpgPreview(templateName);
+                jpgPreview.setAutoRemove(false);
+                jpgPreview.open();
+                jpgPreview.close();
+                QString jpeg_filename = jpgPreview.fileName();
+
+                QString cmd = QString("/bin/sh -c \"dcraw -c -q 0 -w -H 5 -b 8 %1 | cjpeg -quality 80 > %2\"").arg(filename).arg(jpeg_filename);
+                dcraw.start(cmd);
+                dcraw.waitForFinished();
+                filename = jpeg_filename;
+            }
+            else
+            {
+                KStars::Instance()->statusBar()->showMessage(xi18n("Unable to find dcraw and cjpeg. Please install the required tools to convert CR2 to JPEG."));
+                emit BLOBUpdated(bp);
+                return;
+            }
+        }
+
+        QUrl url = QUrl::fromLocalFile(filename);
+        ImageViewer *iv = new ImageViewer(url, QString(), KStars::Instance());
+        if (iv)
+           iv->show();
+    }
     // Unless we have cfitsio, we're done.
-    #ifdef HAVE_CFITSIO_H
-    if (Options::showFITS() && (targetChip->showFITS() || targetChip->getCaptureMode() != FITS_NORMAL)
+    #ifdef HAVE_CFITSIO
+    if (BType == BLOB_FITS && Options::showFITS() && (targetChip->showFITS() || targetChip->getCaptureMode() != FITS_NORMAL)
             && targetChip->getCaptureMode() != FITS_WCSM)
     {
-        KUrl fileURL(filename);
+        QUrl fileURL(filename);
 
         if (fv == NULL)
         {
-            fv = new FITSViewer(KStars::Instance());
+            if (Options::singleWindowFITS())
+                fv = GUIManager::Instance()->getGenericFITSViewer();
+            else
+                fv = new FITSViewer(KStars::Instance());
+
             connect(fv, SIGNAL(destroyed()), this, SLOT(FITSViewerDestroyed()));
             connect(fv, SIGNAL(destroyed()), this, SIGNAL(FITSViewerClosed()));
         }
 
         FITSScale captureFilter = targetChip->getCaptureFilter();
+
+        QString previewTitle;
+
         bool preview = !targetChip->isBatchMode() && Options::singlePreviewFITS();
+        if (preview)
+        {
+            if (Options::singleWindowFITS())
+                previewTitle = xi18n("%1 Preview", getDeviceName());
+            else
+                previewTitle = xi18n("Preview");
+        }
+
 
         switch (targetChip->getCaptureMode())
         {
             case FITS_NORMAL:
                 if (normalTabID == -1 || Options::singlePreviewFITS() == false)
-                    normalTabID = fv->addFITS(&fileURL, FITS_NORMAL, captureFilter, preview);
+                    normalTabID = fv->addFITS(&fileURL, FITS_NORMAL, captureFilter, previewTitle);
                 else if (fv->updateFITS(&fileURL, normalTabID, captureFilter) == false)
-                    normalTabID = fv->addFITS(&fileURL, FITS_NORMAL, captureFilter, preview);
+                    normalTabID = fv->addFITS(&fileURL, FITS_NORMAL, captureFilter, previewTitle);
 
-                targetChip->setImage(fv->getImage(normalTabID), FITS_NORMAL);
+                targetChip->setImage(fv->getView(normalTabID), FITS_NORMAL);
                 break;
 
             case FITS_FOCUS:
@@ -1081,7 +1257,7 @@ void CCD::processBLOB(IBLOB* bp)
                 else if (fv->updateFITS(&fileURL, focusTabID, captureFilter) == false)
                     focusTabID = fv->addFITS(&fileURL, FITS_FOCUS, captureFilter);
 
-                targetChip->setImage(fv->getImage(focusTabID), FITS_FOCUS);
+                targetChip->setImage(fv->getView(focusTabID), FITS_FOCUS);
                 break;
 
         case FITS_GUIDE:
@@ -1090,7 +1266,7 @@ void CCD::processBLOB(IBLOB* bp)
             else if (fv->updateFITS(&fileURL, guideTabID, captureFilter) == false)
                 guideTabID = fv->addFITS(&fileURL, FITS_GUIDE, captureFilter);
 
-            targetChip->setImage(fv->getImage(guideTabID), FITS_GUIDE);
+            targetChip->setImage(fv->getView(guideTabID), FITS_GUIDE);
             break;
 
         case FITS_CALIBRATE:
@@ -1099,7 +1275,7 @@ void CCD::processBLOB(IBLOB* bp)
             else if (fv->updateFITS(&fileURL, calibrationTabID, captureFilter) == false)
                 calibrationTabID = fv->addFITS(&fileURL, FITS_CALIBRATE, captureFilter);
 
-            targetChip->setImage(fv->getImage(calibrationTabID), FITS_CALIBRATE);
+            targetChip->setImage(fv->getView(calibrationTabID), FITS_CALIBRATE);
             break;
 
 
@@ -1119,7 +1295,7 @@ void CCD::processBLOB(IBLOB* bp)
 
 void CCD::addFITSKeywords(QString filename)
 {
-#ifdef HAVE_CFITSIO_H
+#ifdef HAVE_CFITSIO
     int status=0;
 
     if (filter.isEmpty() == false)
@@ -1129,7 +1305,7 @@ void CCD::addFITSKeywords(QString filename)
 
         fitsfile* fptr=NULL;
 
-        if (fits_open_image(&fptr, filename.toAscii(), READWRITE, &status))
+        if (fits_open_image(&fptr, filename.toLatin1(), READWRITE, &status))
         {
             fits_report_error(stderr, status);
             return;
@@ -1156,7 +1332,9 @@ void CCD::FITSViewerDestroyed()
 
 void CCD::StreamWindowHidden()
 {
-        ISwitchVectorProperty *streamSP = baseDevice->getSwitch("VIDEO_STREAM");
+        ISwitchVectorProperty *streamSP = baseDevice->getSwitch("CCD_VIDEO_STREAM");
+        if (streamSP == NULL)
+            streamSP = baseDevice->getSwitch("VIDEO_STREAM");
         if (streamSP)
         {
             IUResetSwitch(streamSP);
@@ -1173,6 +1351,11 @@ bool CCD::hasGuideHead()
     return HasGuideHead;
 }
 
+bool CCD::hasCooler()
+{
+    return HasCooler;
+}
+
 CCDChip * CCD::getChip(CCDChip::ChipType cType)
 {
     switch (cType)
@@ -1305,5 +1488,36 @@ CCD::UploadMode CCD::getUploadMode()
     return UPLOAD_CLIENT;
 }
 
+bool CCD::getTemperature(double *value)
+{
+    if (HasCooler == false)
+        return false;
+
+    INumberVectorProperty *temperatureNP = baseDevice->getNumber("CCD_TEMPERATURE");
+    if (temperatureNP == NULL)
+        return false;
+
+    *value = temperatureNP->np[0].value;
+
+    return true;
+
+}
+
+bool CCD::setTemperature(double value)
+{
+    INumberVectorProperty *nvp = baseDevice->getNumber("CCD_TEMPERATURE");
+    if (nvp == NULL)
+        return false;
+
+    INumber *np = IUFindNumber(nvp, "CCD_TEMPERATURE_VALUE");
+    if (np == NULL)
+        return false;
+
+    np->value = value;
+
+    clientManager->sendNewNumber(nvp);
+
+    return true;
+}
 
 }
