@@ -29,12 +29,12 @@
 #include <QDoubleSpinBox>
 #include <QDebug>
 
-#include <KPushButton>
+#include <QPushButton>
 #include <KSqueezedTextLabel>
-#include <KLineEdit>
-#include <KLocale>
+#include <QLineEdit>
+#include <KLocalizedString>
 #include <KLed>
-#include <KFileDialog>
+#include <QFileDialog>
 #include <KMessageBox>
 
 extern const char *libindi_strings_context;
@@ -49,7 +49,6 @@ INDI_E::INDI_E(INDI_P *gProp, INDI::Property *dProp)
 
   EHBox     = new QHBoxLayout;
   EHBox->setMargin(0);
-  EHBox->setSpacing(KDialog::spacingHint());
 
   tp        = NULL;
   sp        = NULL;
@@ -85,7 +84,7 @@ INDI_E::~INDI_E()
 void INDI_E::buildSwitch(QButtonGroup* groupB, ISwitch *sw)
 {
     name  = sw->name;
-    label = i18nc(libindi_strings_context, sw->label);
+    label = xi18nc(libindi_strings_context, sw->label);
 
     if (label == "(I18N_EMPTY_MESSAGE)")
         label = sw->label;
@@ -93,7 +92,7 @@ void INDI_E::buildSwitch(QButtonGroup* groupB, ISwitch *sw)
     sp = sw;
 
     if (label.isEmpty())
-        label = i18nc(libindi_strings_context, sw->name);
+        label = xi18nc(libindi_strings_context, sw->name);
 
     if (label == "(I18N_EMPTY_MESSAGE)")
         label = sw->name;
@@ -104,7 +103,8 @@ void INDI_E::buildSwitch(QButtonGroup* groupB, ISwitch *sw)
     switch (guiProp->getGUIType())
     {
     case PG_BUTTONS:
-        push_w = new KPushButton(label, guiProp->getGroup()->getContainer());
+        push_w = new QPushButton(label, guiProp->getGroup()->getContainer());
+        push_w->setCheckable(true);
         groupB->addButton(push_w);
 
         syncSwitch();
@@ -143,7 +143,7 @@ void INDI_E::buildText(IText *itp)
 {
     name  = itp->name;
     if (itp->label[0])
-        label = i18nc(libindi_strings_context, itp->label);
+        label = xi18nc(libindi_strings_context, itp->label);
 
     if (label == "(I18N_EMPTY_MESSAGE)")
         label = itp->label;
@@ -151,7 +151,7 @@ void INDI_E::buildText(IText *itp)
     tp = itp;
 
     if (label.isEmpty())
-        label = i18nc(libindi_strings_context, itp->name);
+        label = xi18nc(libindi_strings_context, itp->name);
 
     if (label == "(I18N_EMPTY_MESSAGE)")
         label = itp->name;
@@ -159,7 +159,7 @@ void INDI_E::buildText(IText *itp)
     setupElementLabel();
 
     if (tp->text[0])
-        text = i18nc(libindi_strings_context, tp->text);
+        text = xi18nc(libindi_strings_context, tp->text);
 
     switch (dataProp->getPermission())
     {
@@ -218,15 +218,17 @@ void INDI_E::syncSwitch()
     {
        case PG_BUTTONS:
         if (sp->s == ISS_ON)
-        {
-            push_w->setDown(true);
+        {                       
+            push_w->setChecked(true);
+            //push_w->setDown(true);
             buttonFont = push_w->font();
             buttonFont.setBold(true);
             push_w->setFont(buttonFont);
         }
         else
-        {
-            push_w->setDown(false);
+        {            
+            push_w->setChecked(false);
+            //push_w->setDown(false);
             buttonFont = push_w->font();
             buttonFont.setBold(false);
             push_w->setFont(buttonFont);
@@ -252,7 +254,7 @@ void INDI_E::syncText()
     if (tp == NULL)
         return;
 
-    read_w->setText(i18nc(libindi_strings_context, tp->text));
+    read_w->setText(xi18nc(libindi_strings_context, tp->text));
 
 }
 
@@ -332,7 +334,7 @@ void INDI_E::setText(const QString &newText)
 void INDI_E::buildBLOB(IBLOB *ibp)
 {
     name  = ibp->name;
-    label = i18nc(libindi_strings_context, ibp->label);
+    label = xi18nc(libindi_strings_context, ibp->label);
 
     if (label == "(I18N_EMPTY_MESSAGE)")
         label = ibp->label;
@@ -340,14 +342,14 @@ void INDI_E::buildBLOB(IBLOB *ibp)
     bp = ibp;
 
     if (label.isEmpty())
-        label = i18nc(libindi_strings_context, ibp->name);
+        label = xi18nc(libindi_strings_context, ibp->name);
 
     if (label == "(I18N_EMPTY_MESSAGE)")
         label = ibp->name;
 
     setupElementLabel();
 
-    text = i18n("INDI DATA STREAM");
+    text = xi18n("INDI DATA STREAM");
 
     switch (dataProp->getPermission())
     {
@@ -377,7 +379,7 @@ void INDI_E::buildNumber  (INumber *inp)
     char iNumber[32];
 
     name  = inp->name;
-    label = i18nc(libindi_strings_context, inp->label);
+    label = xi18nc(libindi_strings_context, inp->label);
 
     if (label == "(I18N_EMPTY_MESSAGE)")
         label = inp->label;
@@ -385,7 +387,7 @@ void INDI_E::buildNumber  (INumber *inp)
     np = inp;
 
     if (label.isEmpty())
-        label = i18nc(libindi_strings_context, inp->name);
+        label = xi18nc(libindi_strings_context, inp->name);
 
     if (label == "(I18N_EMPTY_MESSAGE)")
         label = inp->name;
@@ -431,7 +433,7 @@ void INDI_E::buildNumber  (INumber *inp)
 void INDI_E::buildLight(ILight *ilp)
 {
     name  = ilp->name;
-    label = i18nc(libindi_strings_context, ilp->label);
+    label = xi18nc(libindi_strings_context, ilp->label);
 
     if (label == "(I18N_EMPTY_MESSAGE)")
         label = ilp->label;
@@ -439,7 +441,7 @@ void INDI_E::buildLight(ILight *ilp)
     lp = ilp;
 
     if (label.isEmpty())
-        label = i18nc(libindi_strings_context, ilp->name);
+        label = xi18nc(libindi_strings_context, ilp->name);
 
     if (label == "(I18N_EMPTY_MESSAGE)")
         label = ilp->name;
@@ -576,7 +578,7 @@ void INDI_E::setMax ()
 void INDI_E::setupElementWrite(int length)
 {
 
-    write_w = new KLineEdit( guiProp->getGroup()->getContainer());
+    write_w = new QLineEdit( guiProp->getGroup()->getContainer());
     write_w->setSizePolicy( QSizePolicy::Preferred, QSizePolicy::Preferred);
     write_w->setMinimumWidth( length );
     write_w->setMaximumWidth( length);
@@ -594,7 +596,7 @@ void INDI_E::setupElementRead(int length)
 {
 
 
-    read_w = new KLineEdit( guiProp->getGroup()->getContainer() );
+    read_w = new QLineEdit( guiProp->getGroup()->getContainer() );
     read_w->setMinimumWidth( length );
     read_w->setFocusPolicy( Qt::NoFocus );
     read_w->setCursorPosition( 0 );
@@ -609,7 +611,7 @@ void INDI_E::setupElementRead(int length)
 
 void INDI_E::setupBrowseButton()
 {
-    browse_w = new KPushButton("...", guiProp->getGroup()->getContainer());
+    browse_w = new QPushButton("...", guiProp->getGroup()->getContainer());
     browse_w->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
     browse_w->setMinimumWidth( MIN_SET_WIDTH );
     browse_w->setMaximumWidth( MAX_SET_WIDTH );
@@ -628,9 +630,9 @@ void INDI_E::browseBlob()
     QDataStream binaryStream;
     int data64_size=0, pos=0;
     unsigned char *data_file;
-    KUrl currentURL;
+    QUrl currentURL;
 
-    currentURL = KFileDialog::getOpenUrl( QDir::homePath(), "*");
+    currentURL = QFileDialog::getOpenFileUrl();
 
     // if user presses cancel
     if (currentURL.isEmpty())
@@ -648,7 +650,7 @@ void INDI_E::browseBlob()
 
     if (!fp.open(QIODevice::ReadOnly))
     {
-        KMessageBox::error(0, i18n("Cannot open file %1 for reading", filename));
+        KMessageBox::error(0, xi18n("Cannot open file %1 for reading", filename));
         return;
     }
 
@@ -660,7 +662,7 @@ void INDI_E::browseBlob()
 
     if (data_file == NULL)
     {
-        KMessageBox::error(0, i18n("Not enough memory to load %1", filename));
+        KMessageBox::error(0, xi18n("Not enough memory to load %1", filename));
         fp.close();
         return;
     }
@@ -670,7 +672,7 @@ void INDI_E::browseBlob()
     bp->blob = new unsigned char[4*fp.size()/3+4];
     if (bp->blob == NULL)
     {
-        KMessageBox::error(0, i18n("Not enough memory to convert file %1 to base64", filename));
+        KMessageBox::error(0, xi18n("Not enough memory to convert file %1 to base64", filename));
         fp.close();
     }
 
@@ -702,4 +704,4 @@ QString INDI_E::getReadField()
         return NULL;
 }
 
-#include "indielement.moc"
+
