@@ -19,12 +19,11 @@
 #include "indicommon.h"
 #include "fitsviewer/fitscommon.h"
 
+#define MAXINDIFILENAME 512
 
 class ClientManager;
-class FITSViewer;
 class DriverInfo;
 class DeviceInfo;
-class StreamWG;
 
 // INDI Standard Device Namespace
 namespace ISD
@@ -45,6 +44,16 @@ public:
 
 };
 
+/**
+ * @class GDInterface
+ *  GDInterface is the Generic Device <i>Interface</i> for INDI devices. It is used as part of the Decorater Pattern when initally a new INDI device is created as a
+ * Generic Device in INDIListener. If the device registers an INDI Standard Property belonging to one specific device type (e.g. Telescope), then the device functionality
+ * is extended to the particular device type.
+ *
+ * DeviceDecorator subclasses GDInterface and calls concrete decorators methods.
+ *
+ * @author Jasem Mutlaq
+ */
 class GDInterface : public QObject
 {
     Q_OBJECT
@@ -71,6 +80,8 @@ public:
     virtual const char *getDeviceName()=0;
     virtual bool isConnected()=0;
     virtual bool getMinMaxStep(const QString & propName, const QString & elementName, double *min, double *max, double *step)=0;
+    virtual IPState getState(const QString &propName)=0;
+    virtual IPerm getPermission(const QString &propName)=0;
 
     virtual ~GDInterface() {}
 
@@ -99,9 +110,18 @@ signals:
 
 };
 
+/**
+ * @class GenericDevice
+ * GenericDevice is the Generic Device for INDI devices. When a new INDI device is created in INDIListener, it gets created as a GenericDevice initially. If the device
+ * registers a standard property that is a key property to a device type family (e.g. Number property EQUATORIAL_EOD_COORD signifies a Telescope device), then the specialized version of
+ * the device is exnteded via the Decorater Pattern.
+ *
+ * GenericDevice handles common functions shared across many devices such as time and location handling, configuration processing, retrieving information about properties, driver info..etc.
+ *
+ * @author Jasem Mutlaq
+ */
 class GenericDevice : public GDInterface
 {
-
     Q_OBJECT
 
 public:
@@ -127,6 +147,8 @@ public:
     virtual bool isConnected() { return connected; }
     virtual INDI::BaseDevice* getBaseDevice() { return baseDevice;}
     virtual bool getMinMaxStep(const QString & propName, const QString & elementName, double *min, double *max, double *step);
+    virtual IPState getState(const QString &propName);
+    virtual IPerm getPermission(const QString &propName);
 
 public slots:
     virtual bool Connect();
@@ -141,14 +163,20 @@ protected:
 
 private:
     bool connected;
-
     DriverInfo *driverInfo;
     DeviceInfo *deviceInfo;
     INDI::BaseDevice *baseDevice;
     ClientManager *clientManager;
+    char BLOBFilename[MAXINDIFILENAME];
 
 };
 
+/**
+ * @class DeviceDecorator
+ * DeviceDecorator is the base decorater for all specialized devices. It extends the functionality of GenericDevice.
+ *
+ * @author Jasem Mutlaq
+ */
 class DeviceDecorator : public GDInterface
 {
     Q_OBJECT
@@ -177,6 +205,8 @@ public:
     virtual INDI::BaseDevice* getBaseDevice();
 
     bool getMinMaxStep(const QString & propName, const QString & elementName, double *min, double *max, double *step);
+    IPState getState(const QString &propName);
+    IPerm getPermission(const QString &propName);
 
 
 public slots:
@@ -192,6 +222,15 @@ protected:
 
 };
 
+/**
+ * @class ST4
+ * ST4 is a special class that handles ST4 commands. Since ST4 functionalty can be part of a stand alone ST4 device,
+ * or as part of a larger device as CCD or Telescope, it is handled separately to enable one ST4 device regardless of the parent device type.
+ *
+ *  ST4 is a hardware port dedicated to sending guiding correction pulses to the mount.
+ *
+ * @author Jasem Mutlaq
+ */
 class ST4
 {
 public:
