@@ -19,14 +19,14 @@
 
 #include <QApplication>
 #include <QDockWidget>
+#include <QDebug>
+#include <QStatusBar>
+#include <QIcon>
 
-#include <KGlobal>
-#include <KLocale>
-#include <kdebug.h>
-#include <kactioncollection.h>
-#include <kstatusbar.h>
-#include <ktoolbar.h>
-#include <kicon.h>
+#include <KLocalizedString>
+#include <KActionCollection>
+#include <KToolBar>
+#include <KSharedConfig>
 
 #include "Options.h"
 #include "kstarsdata.h"
@@ -38,35 +38,39 @@
 #include "dialogs/finddialog.h"
 #include "dialogs/exportimagedialog.h"
 #include "observinglist.h"
-#include "oal/execute.h"
 #include "whatsinteresting/wiview.h"
 
 #include "kstarsadaptor.h"
 
 #include <config-kstars.h>
 
-#ifdef HAVE_INDI_H
-//#include "indi/indimenu.h"
-//#include "indi/indidriver.h"
-//#include "indi/imagesequence.h"
+#ifdef HAVE_INDI
 #include "indi/drivermanager.h"
+#include "ekos/ekosmanager.h"
 #endif
 
 KStars *KStars::pinstance = 0;
 
 KStars::KStars( bool doSplash, bool clockrun, const QString &startdate )
-    : KXmlGuiWindow(), kstarsData(0), skymap(0), TimeStep(0),
-      colorActionMenu(0), fovActionMenu(0), findDialog(0),
-      imgExportDialog(0), imageExporter(0), obsList(0), execute(0),
-      avt(0), wut(0), wi(0), wiObsConditions(0), wiDock(0), skycal(0),
-      sb(0), pv(0), jmt(0), mpt(0), fm(0), astrocalc(0), printingWizard(0),
-      ekosmenu(0), DialogIsObsolete(false), StartClockRunning( clockrun ),
+    : KXmlGuiWindow(), colorActionMenu(0), fovActionMenu(0), m_KStarsData(0), m_SkyMap(0), m_TimeStepBox(0),
+      m_ExportImageDialog(0),  m_PrintingWizard(0), m_FindDialog(0),
+      m_AstroCalc(0), m_AltVsTime(0), m_SkyCalendar(0), m_ScriptBuilder(0),
+      m_PlanetViewer(0), m_WUTDialog(0), m_JMoonTool(0), m_MoonPhaseTool(0), m_FlagManager(0),
+      //FIXME Port to QML2
+      #if 0
+      m_WIView(0), m_ObsConditions(0), m_wiDock(0),
+      #endif
+      DialogIsObsolete(false), StartClockRunning( clockrun ),
       StartDateString( startdate )
 {
     new KstarsAdaptor(this);
     QDBusConnection::sessionBus().registerObject("/KStars",  this);
     QDBusConnection::sessionBus().registerService("org.kde.kstars");
 
+    #ifdef HAVE_INDI
+    m_EkosManager = NULL;
+    #endif
+
     // Set pinstance to yourself
     pinstance = this;
 
@@ -76,17 +80,17 @@ KStars::KStars( bool doSplash, bool clockrun, const QString &startdate )
     projectionGroup = new QActionGroup( this );
     cschemeGroup    = new QActionGroup( this );
 
-    kstarsData = KStarsData::Create();
-    Q_ASSERT( kstarsData );
+    m_KStarsData = KStarsData::Create();
+    Q_ASSERT( m_KStarsData );
     //Set Geographic Location from Options
-    kstarsData->setLocationFromOptions();
+    m_KStarsData->setLocationFromOptions();
 
     //Initialize Time and Date
     KStarsDateTime startDate = KStarsDateTime::fromString( StartDateString );
     if ( ! StartDateString.isEmpty() && startDate.isValid() )
         data()->changeDateTime( data()->geo()->LTtoUT( startDate ) );
     else
-        data()->changeDateTime( KStarsDateTime::currentUtcDateTime() );
+        data()->changeDateTime( KStarsDateTime::currentDateTimeUtc() );
 
     // Initialize clock. If --paused is not in the comand line, look in options
     if ( clockrun )
@@ -96,10 +100,10 @@ KStars::KStars( bool doSplash, bool clockrun, const QString &startdate )
     KStarsSplash *splash = 0;
     if ( doSplash ) {
         splash = new KStarsSplash(0);
-        connect( kstarsData, SIGNAL( progressText(QString) ), splash, SLOT( setMessage(QString) ));
+        connect( m_KStarsData, SIGNAL( progressText(QString) ), splash, SLOT( setMessage(QString) ));
         splash->show();
     } else {
-        connect( kstarsData, SIGNAL( progressText(QString) ), kstarsData, SLOT( slotConsoleMessage(QString) ) );
+        connect( m_KStarsData, SIGNAL( progressText(QString) ), m_KStarsData, SLOT( slotConsoleMessage(QString) ) );
     }
 
     //set up Dark color scheme for application windows
@@ -114,15 +118,15 @@ KStars::KStars( bool doSplash, bool clockrun, const QString &startdate )
     OriginalPalette = QApplication::palette();
 
     //Initialize data.  When initialization is complete, it will run dataInitFinished()
-    if( !kstarsData->initialize() )
+    if( !m_KStarsData->initialize() )
         return;
     delete splash;
     datainitFinished();
 
 #if ( __GLIBC__ >= 2 &&__GLIBC_MINOR__ >= 1  && !defined(__UCLIBC__) )
-    kDebug() << "glibc >= 2.1 detected.  Using GNU extension sincos()";
+    qDebug() << "glibc >= 2.1 detected.  Using GNU extension sincos()";
 #else
-    kDebug() << "Did not find glibc >= 2.1.  Will use ANSI-compliant sin()/cos() functions.";
+    qDebug() << "Did not find glibc >= 2.1.  Will use ANSI-compliant sin()/cos() functions.";
 #endif
 }
 
@@ -138,11 +142,12 @@ KStars::~KStars()
 {
     Q_ASSERT( pinstance );
 
-    #ifdef HAVE_INDI_H
+    #ifdef HAVE_INDI
     DriverManager::Instance()->clearServers();
+    delete m_EkosManager;
     #endif
 
-    delete kstarsData;
+    delete m_KStarsData;
     pinstance = 0;
 
     QSqlDatabase::removeDatabase("userdb");
@@ -150,11 +155,11 @@ KStars::~KStars()
 }
 
 void KStars::clearCachedFindDialog() {
-    if ( findDialog  ) {  // dialog is cached
+    if ( m_FindDialog  ) {  // dialog is cached
         /** Delete findDialog only if it is not opened */
-        if ( findDialog->isHidden() ) {
-            delete findDialog;
-            findDialog = 0;
+        if ( m_FindDialog->isHidden() ) {
+            delete m_FindDialog;
+            m_FindDialog = 0;
             DialogIsObsolete = false;
         }
         else
@@ -164,16 +169,16 @@ void KStars::clearCachedFindDialog() {
 
 void KStars::applyConfig( bool doApplyFocus ) {
     if ( Options::isTracking() ) {
-        actionCollection()->action("track_object")->setText( i18n( "Stop &Tracking" ) );
-        actionCollection()->action("track_object")->setIcon( KIcon("document-encrypt") );
+        actionCollection()->action("track_object")->setText( xi18n( "Stop &Tracking" ) );
+        actionCollection()->action("track_object")->setIcon( QIcon::fromTheme("document-encrypt") );
     }
 
     actionCollection()->action("coordsys")->setText(
-        Options::useAltAz() ? i18n("Switch to star globe view (Equatorial &Coordinates)"): i18n("Switch to horizonal view (Horizontal &Coordinates)") );
+        Options::useAltAz() ? xi18n("Switch to star globe view (Equatorial &Coordinates)"): xi18n("Switch to horizonal view (Horizontal &Coordinates)") );
 
     #ifdef HAVE_OPENGL
     Q_ASSERT( SkyMap::Instance() ); // This assert should not fail, because SkyMap is already created by now. Just throwing it in anyway.
-    actionCollection()->action("opengl")->setText( (Options::useGL() ? i18n("Switch to QPainter backend"): i18n("Switch to OpenGL backend")) );
+    actionCollection()->action("opengl")->setText( (Options::useGL() ? xi18n("Switch to QPainter backend"): xi18n("Switch to OpenGL backend")) );
     #endif
 
 
@@ -198,12 +203,12 @@ void KStars::applyConfig( bool doApplyFocus ) {
     statusBar()->setVisible( Options::showStatusBar() );
 
     //color scheme
-    kstarsData->colorScheme()->loadFromConfig();
+    m_KStarsData->colorScheme()->loadFromConfig();
     QApplication::setPalette( Options::darkAppColors() ? DarkPalette : OriginalPalette );
 
     //Set toolbar options from config file
-    toolBar("kstarsToolBar")->applySettings( KGlobal::config()->group( "MainToolBar" ) );
-    toolBar( "viewToolBar" )->applySettings( KGlobal::config()->group( "ViewToolBar" ) );
+    toolBar("kstarsToolBar")->applySettings( KSharedConfig::openConfig()->group( "MainToolBar" ) );
+    toolBar( "viewToolBar" )->applySettings( KSharedConfig::openConfig()->group( "ViewToolBar" ) );
 
     //Geographic location
     data()->setLocationFromOptions();
@@ -228,8 +233,8 @@ void KStars::applyConfig( bool doApplyFocus ) {
 }
 
 void KStars::showImgExportDialog() {
-    if(imgExportDialog)
-        imgExportDialog->show();
+    if(m_ExportImageDialog)
+        m_ExportImageDialog->show();
 }
 
 void KStars::syncFOVActions() {
@@ -326,10 +331,13 @@ void KStars::selectPreviousFov()
     map()->update();
 }
 
+//FIXME Port to QML2
+#if 0
 void KStars::showWISettingsUI()
 {
     slotWISettings();
 }
+#endif
 
 void KStars::updateTime( const bool automaticDSTchange ) {
     // Due to frequently use of this function save data and map pointers for speedup.
@@ -360,11 +368,14 @@ void KStars::updateTime( const bool automaticDSTchange ) {
     }
 }
 
-Execute* KStars::getExecute() {
-    if( !execute )
-        execute = new Execute();
-    return execute;
+#ifdef HAVE_INDI
+EkosManager *KStars::ekosManager()
+{
+    if (!m_EkosManager)
+        m_EkosManager   = new EkosManager();
+
+    return m_EkosManager;
 }
 
-#include "kstars.moc"
 
+#endif
