@@ -17,16 +17,16 @@
 
 #include "kstarssplash.h"
 
-#include <klocale.h>
-#include <KStandardDirs>
+#include <KLocalizedString>
+#include <QStandardPaths>
 
 
 KStarsSplash::KStarsSplash(const QString& customMessage )
-        : KSplashScreen(QPixmap() )
+        : QSplashScreen(QPixmap() )
 {
-    setPixmap(KStandardDirs::locate("appdata","kstars.png"));
+    setPixmap(QStandardPaths::locate(QStandardPaths::DataLocation, "kstars.png"));
     setMessage( customMessage.isEmpty() ?
-                      i18n( "Welcome to KStars. Please stand by while loading..." ) :
+                      xi18n( "Welcome to KStars. Please stand by while loading..." ) :
                       customMessage);
 }
 
@@ -37,4 +37,4 @@ void KStarsSplash::setMessage(const QString& message) {
     showMessage( message, Qt::AlignLeft, Qt::lightGray);
 }
 
-#include "kstarssplash.moc"
+
