@@ -22,11 +22,16 @@
 #include "ui_observeradd.h"
 
 #include <QWidget>
-#include <kdialog.h>
+#include <QDialog>
 
 #include "kstars.h"
 
-class ObserverAdd : public KDialog {
+/**
+ * @class ObserverAdd
+ *
+ * Dialog to add new observers.
+ */
+class ObserverAdd : public QDialog {
 Q_OBJECT
     public:
         //The default constructor
@@ -44,7 +49,6 @@ Q_OBJECT
         void slotAddObserver();
 
     private:
-        KStars *ks;
         Ui::ObserverAdd ui;
         int nextObserver;
 };
