@@ -17,9 +17,9 @@
 
 #include "catalogcomponent.h"
 
-#include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <QDebug>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <QDir>
 #include <QFile>
 #include <QPixmap>
@@ -47,7 +47,7 @@ CatalogComponent::~CatalogComponent() {
 }
 
 void CatalogComponent::loadData() {
-    emitProgressText( i18n("Loading custom catalog: %1", m_catName ) );
+    emitProgressText( xi18n("Loading custom catalog: %1", m_catName ) );
 
     QList < QPair <int, QString> > names;
 
