@@ -17,7 +17,7 @@
 
 #include "solarsystemcomposite.h"
 
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "solarsystemsinglecomponent.h"
 #include "asteroidscomponent.h"
@@ -31,13 +31,13 @@
 #include "skyobjects/ksplanet.h"
 #include "skyobjects/kssun.h"
 #include "skyobjects/ksmoon.h"
-#include "skyobjects/kspluto.h"
+//#include "skyobjects/kspluto.h"
 #include "planetmoonscomponent.h"
 
 SolarSystemComposite::SolarSystemComposite(SkyComposite *parent ) :
     SkyComposite(parent)
 {
-    emitProgressText( i18n("Loading solar system" ) );
+    emitProgressText( xi18n("Loading solar system" ) );
     m_Earth = new KSPlanet( I18N_NOOP( "Earth" ), QString(), QColor( "white" ), 12756.28 /*diameter in km*/ );
 
     m_Sun = new KSSun();
@@ -55,7 +55,7 @@ SolarSystemComposite::SolarSystemComposite(SkyComposite *parent ) :
     addComponent( sat );
     addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::URANUS ), Options::showUranus ) );
     addComponent( new SolarSystemSingleComponent( this, new KSPlanet( KSPlanetBase::NEPTUNE ), Options::showNeptune ) );
-    addComponent( new SolarSystemSingleComponent( this, new KSPluto(), Options::showPluto ) );
+    //addComponent( new SolarSystemSingleComponent( this, new KSPluto(), Options::showPluto ) );
 
     addComponent( m_AsteroidsComponent = new AsteroidsComponent( this  ));
     addComponent( m_CometsComponent    = new CometsComponent( this ));
@@ -100,7 +100,7 @@ void SolarSystemComposite::updateMoons( KSNumbers *num )
     KStarsData *data = KStarsData::Instance(); 
     m_Sun->findPosition( num );
     m_Moon->findPosition( num, data->geo()->lat(), data->lst() );
-    m_Moon->findPhase();
+    m_Moon->findPhase(0);
     m_JupiterMoons->updateMoons( num );
 }
 
