@@ -62,7 +62,7 @@ SkyGLPainter::SkyGLPainter( QGLWidget *widget ) :
 {
     m_widget = widget;
     if( !m_init ) {
-        kDebug() << "Initializing texcoord arrays...\n";
+        qDebug() << "Initializing texcoord arrays...\n";
         for(int i = 0; i < NUMTYPES; ++i) {
             m_idx[i] = 0;
             for(int j = 0; j < BUFSIZE; ++j) {
@@ -242,11 +242,11 @@ bool SkyGLPainter::drawPlanet(KSPlanetBase* planet)
         // Draw them as bright stars of appropriate color instead of images
         char spType;
         //FIXME: do these need i18n?
-        if( planet->name() == i18n( "Sun" ) ) {
+        if( planet->name() == xi18n( "Sun" ) ) {
             spType = 'G';
-        } else if( planet->name() == i18n("Mars") ) {
+        } else if( planet->name() == xi18n("Mars") ) {
             spType = 'K';
-        } else if( planet->name() == i18n("Jupiter") || planet->name() == i18n("Mercury") || planet->name() == i18n("Saturn") ) {
+        } else if( planet->name() == xi18n("Jupiter") || planet->name() == xi18n("Mercury") || planet->name() == xi18n("Saturn") ) {
             spType = 'F';
         } else {
             spType = 'B';
