@@ -19,8 +19,8 @@
 
 #include "skypoint.h"
 
-#include <kdebug.h>
-#include <klocale.h>
+#include <QDebug>
+#include <KLocalizedString>
 
 #include "skyobject.h"
 #include "dms.h"
@@ -121,10 +121,10 @@ void SkyPoint::HorizontalToEquatorial( const dms *LST, const dms *lat ) {
     if ( x < -1.0 && x > -1.000001 ) HARad = dms::PI;
     else if ( x > 1.0 && x < 1.000001 ) HARad = 0.0;
     else if ( x < -1.0 ) {
-        kWarning() << i18n( "Coordinate out of range." ) << endl;
+        qWarning() << xi18n( "Coordinate out of range." ) << endl;
         HARad = dms::PI;
     } else if ( x > 1.0 ) {
-        kWarning() << i18n( "Coordinate out of range." ) << endl;
+        qWarning() << xi18n( "Coordinate out of range." ) << endl;
         HARad = 0.0;
     } else HARad = acos( x );
 
@@ -191,7 +191,8 @@ SkyPoint SkyPoint::deprecess( const KSNumbers *num, long double epoch ) {
     SkyPoint p1( RA, Dec );
     long double now = num->julianDay();
     p1.precessFromAnyEpoch( now, epoch );
-    if( RA0.Degrees() < 0.0 || Dec0.Degrees() > 90.0 ) {
+    if( ( std::isnan( RA0.Degrees() ) || std::isnan( Dec0.Degrees() ) ) ||
+        ( !std::isnan( Dec0.Degrees() ) && fabs( Dec0.Degrees() ) > 90.0 ) ) {
         // We have invalid RA0 and Dec0, so set them.
         RA0 = p1.ra();
         Dec0 = p1.dec();
@@ -227,11 +228,11 @@ void SkyPoint::nutate(const KSNumbers *num) {
     }
 }
 
-SkyPoint SkyPoint::moveAway( const SkyPoint &from, double dist ){
+SkyPoint SkyPoint::moveAway( const SkyPoint &from, double dist ) const {
     dms lat1, dtheta;
 
     if( dist == 0.0 ) {
-        kDebug() << "moveThrough called with zero distance!";
+        qDebug() << "moveAway called with zero distance!";
         return *this;
     }
 
@@ -355,14 +356,14 @@ void SkyPoint::updateCoords( KSNumbers *num, bool /*includePlanets*/, const dms
         precess(num);
         nutate(num);
         if( lens )
-            bendlight();
+            bendlight(); // FIXME: Shouldn't we apply this on the horizontal coordinates?
         aberrate(num);
         lastPrecessJD = num->getJD();
         Q_ASSERT( std::isfinite( RA.Degrees() ) && std::isfinite( Dec.Degrees() ) );
     }
 
     if ( lat || LST )
-        kWarning() << i18n( "lat and LST parameters should only be used in KSPlanetBase objects." ) ;
+        qWarning() << xi18n( "lat and LST parameters should only be used in KSPlanetBase objects." ) ;
 }
 
 void SkyPoint::precessFromAnyEpoch(long double jd0, long double jdf){
@@ -759,7 +760,7 @@ double SkyPoint::vTopocentric(double vgeo, double vsite[3])
     return vgeo - vRSite(vsite);
 }
 
-bool SkyPoint::checkCircumpolar( const dms *gLat ) {
+bool SkyPoint::checkCircumpolar( const dms *gLat ) const {
     return fabs(dec().Degrees())  >  (90 - fabs(gLat->Degrees()));
 }
 
