@@ -23,13 +23,13 @@
 
 #include <QList>
 
-#include "kstars/dms.h"
-#include "kstars/kstarsdatetime.h"
+#include "dms.h"
+#include "kstarsdatetime.h"
 
 class KSNumbers;
 class KSSun;
 
-/**@class SkyPoint
+/** @class SkyPoint
 	*
 	*The sky coordinates of a point in the sky.  The
 	*coordinates are stored in both Equatorial (Right Ascension,
@@ -49,7 +49,7 @@ class KSSun;
 	*/
 class SkyPoint {
 public:
-    /**Default constructor: Sets RA, Dec and RA0, Dec0 according
+    /** Default constructor: Sets RA, Dec and RA0, Dec0 according
     	*to arguments.  Does not set Altitude or Azimuth.
     	*@param r Right Ascension
     	*@param d Declination
@@ -62,7 +62,7 @@ public:
     {}
 
     
-    /**Alternate constructor using double arguments, for convenience.
+    /** Alternate constructor using double arguments, for convenience.
      *It behaves essentially like the default constructor.
      *@param r Right Ascension, expressed as a double
      *@param d Declination, expressed as a double
@@ -88,75 +88,77 @@ public:
     //// 1.  Setting Coordinates
     //// =======================
 
-    /**Sets RA, Dec and RA0, Dec0 according to arguments.
-     * Does not set Altitude or Azimuth.
+    /**
+     * @short Sets RA, Dec and RA0, Dec0 according to arguments.
+     *        Does not set Altitude or Azimuth.
      * @param r Right Ascension
      * @param d Declination
      * @note This function also sets RA0 and Dec0 to the same values, so call at your own peril!
+     * @note FIXME: This method must be removed, or an epoch argument must be added.
      */
     void set( const dms& r, const dms& d );
 
-    /**Sets RA0, the catalog Right Ascension.
+    /** Sets RA0, the catalog Right Ascension.
     	*@param r catalog Right Ascension.
     	*/
     inline void setRA0( dms r ) { RA0 = r; }
 
-    /**Overloaded member function, provided for convenience.
+    /** Overloaded member function, provided for convenience.
     	*It behaves essentially like the above function.
     	*@param r Right Ascension, expressed as a double.
     	*/
     inline void setRA0( double r ) { RA0.setH( r ); }
 
-    /**Sets Dec0, the catalog Declination.
+    /** Sets Dec0, the catalog Declination.
     	*@param d catalog Declination.
     	*/
     inline void setDec0( dms d ) { Dec0 = d; }
 
-    /**Overloaded member function, provided for convenience.
+    /** Overloaded member function, provided for convenience.
     	*It behaves essentially like the above function.
     	*@param d Declination, expressed as a double.
     	*/
     inline void setDec0( double d ) { Dec0.setD( d ); }
 
-    /**Sets RA, the current Right Ascension.
+    /** Sets RA, the current Right Ascension.
     	*@param r Right Ascension.
     	*/
     inline void setRA( dms r ) { RA = r; }
 
-    /**Overloaded member function, provided for convenience.
+    /** Overloaded member function, provided for convenience.
     	*It behaves essentially like the above function.
     	*@param r Right Ascension, expressed as a double.
     	*/
     inline void setRA( double r ) { RA.setH( r ); }
 
-    /**Sets Dec, the current Declination
+    /** Sets Dec, the current Declination
     	*@param d Declination.
     	*/
     inline void setDec( dms d ) { Dec = d; }
 
-    /**Overloaded member function, provided for convenience.
+    /** Overloaded member function, provided for convenience.
     	*It behaves essentially like the above function.
     	*@param d Declination, expressed as a double.
     	*/
     inline void setDec( double d ) { Dec.setD( d ); }
 
-    /**Sets Alt, the Altitude.
+    /** Sets Alt, the Altitude.
     	*@param alt Altitude.
     	*/
     inline void setAlt( dms alt ) { Alt = alt; }
 
-    /**Overloaded member function, provided for convenience.
+    /** Overloaded member function, provided for convenience.
     	*It behaves essentially like the above function.
     	*@param alt Altitude, expressed as a double.
     	*/
     inline void setAlt( double alt ) { Alt.setD( alt ); }
 
-    /**Sets Az, the Azimuth.
+    /** Sets Az, the Azimuth.
     	*@param az Azimuth.
     	*/
     inline void setAz( dms az ) { Az = az; }
 
-    /**Overloaded member function, provided for convenience.
+    /** Overloaded member function, provided for convenience.
     	*It behaves essentially like the above function.
     	*@param az Azimuth, expressed as a double.
     	*/
@@ -166,34 +168,34 @@ public:
     //// 2. Returning coordinates.
     //// =========================
 
-    /**@return a pointer to the catalog Right Ascension. */
+    /** @return a pointer to the catalog Right Ascension. */
     inline const dms& ra0() const { return RA0; }
 
-    /**@return a pointer to the catalog Declination. */
+    /** @return a pointer to the catalog Declination. */
     inline const dms& dec0() const { return Dec0; }
 
-    /**@returns a pointer to the current Right Ascension. */
+    /** @returns a pointer to the current Right Ascension. */
     inline const dms& ra() const { return RA; }
 
-    /**@return a pointer to the current Declination. */
+    /** @return a pointer to the current Declination. */
     inline const dms& dec() const { return Dec; }
 
-    /**@return a pointer to the current Azimuth. */
+    /** @return a pointer to the current Azimuth. */
     inline const dms& az() const { return Az; }
 
-    /**@return a pointer to the current Altitude. */
+    /** @return a pointer to the current Altitude. */
     inline const dms& alt() const { return Alt; }
 
-    /**@return refracted altitude. This function uses
-     * Option::useRefraction to determine whether refraction
-     * correction should be aplied */
+    /** @return refracted altitude. This function uses
+     * Options::useRefraction to determine whether refraction
+     * correction should be applied */
     dms altRefracted() const;
 
     ////
     //// 3. Coordinate conversions.
     //// ==========================
 
-    /**Determine the (Altitude, Azimuth) coordinates of the
+    /** Determine the (Altitude, Azimuth) coordinates of the
     	*SkyPoint from its (RA, Dec) coordinates, given the local
     	*sidereal time and the observer's latitude.
     	*@param LST pointer to the local sidereal time
@@ -201,7 +203,7 @@ public:
     	*/
     void EquatorialToHorizontal( const dms* LST, const dms* lat );
 
-    /**Determine the (RA, Dec) coordinates of the
+    /** Determine the (RA, Dec) coordinates of the
     	*SkyPoint from its (Altitude, Azimuth) coordinates, given the local
     	*sidereal time and the observer's latitude.
     	*@param LST pointer to the local sidereal time
@@ -209,13 +211,13 @@ public:
     	*/
     void HorizontalToEquatorial( const dms* LST, const dms* lat );
 
-    /**Determine the Ecliptic coordinates of the SkyPoint, given the Julian Date.
+    /** Determine the Ecliptic coordinates of the SkyPoint, given the Julian Date.
     	*The ecliptic coordinates are returned as reference arguments (since
     	*they are not stored internally)
     	*/
     void findEcliptic( const dms *Obliquity, dms &EcLong, dms &EcLat );
 
-    /**Set the current (RA, Dec) coordinates of the
+    /** Set the current (RA, Dec) coordinates of the
     	*SkyPoint, given pointers to its Ecliptic (Long, Lat) coordinates, and
     	*to the current obliquity angle (the angle between the equator and ecliptic).
     	*/
@@ -237,7 +239,7 @@ public:
     //// 4. Coordinate update/corrections.
     //// =================================
 
-    /**Determine the current coordinates (RA, Dec) from the catalog
+    /** Determine the current coordinates (RA, Dec) from the catalog
     	*coordinates (RA0, Dec0), accounting for both precession and nutation.
     	*@param num pointer to KSNumbers object containing current values of
     	*time-dependent variables.
@@ -248,7 +250,7 @@ public:
     	*/
     virtual void updateCoords( KSNumbers *num, bool includePlanets=true, const dms *lat=0, const dms *LST=0, bool forceRecompute = false );
 
-    /**Computes the apparent coordinates for this SkyPoint for any epoch,
+    /** Computes the apparent coordinates for this SkyPoint for any epoch,
     	*accounting for the effects of precession, nutation, and aberration.
     	*Similar to updateCoords(), but the starting epoch need not be
     	*J2000, and the target epoch need not be the present time.
@@ -257,7 +259,7 @@ public:
     	*/
     void apparentCoord(long double jd0, long double jdf);
 
-    /**Determine the effects of nutation for this SkyPoint.
+    /** Determine the effects of nutation for this SkyPoint.
     	*@param num pointer to KSNumbers object containing current values of
     	*time-dependent variables.
     	*/
@@ -269,7 +271,7 @@ public:
      */
     bool checkBendLight();
 
-    /**Correct for the effect of "bending" of light around the sun for
+    /** Correct for the effect of "bending" of light around the sun for
      * positions near the sun.
      *
      * General Relativity tells us that a photon with an impact
@@ -287,13 +289,13 @@ public:
      */
     SkyPoint deprecess( const KSNumbers *num, long double epoch=J2000 );
 
-    /**Determine the effects of aberration for this SkyPoint.
+    /** Determine the effects of aberration for this SkyPoint.
     	*@param num pointer to KSNumbers object containing current values of
     	*time-dependent variables.
     	*/
     void aberrate(const KSNumbers *num);
 
-    /**General case of precession. It precess from an original epoch to a
+    /** General case of precession. It precess from an original epoch to a
     	*final epoch. In this case RA0, and Dec0 from SkyPoint object represent
     	*the coordinates for the original epoch and not for J2000, as usual.
     	*@param jd0 Julian Day which identifies the original epoch
@@ -367,6 +369,9 @@ public:
      **/
     dms angularDistanceTo(const SkyPoint *sp, double * const positionAngle = 0) const;
 
+    /**
+     * @return returns true if _current_ epoch RA / Dec match
+     */
     inline bool operator == ( SkyPoint &p ) const { return ( ra() == p.ra() && dec() == p.dec() ); }
 
     /** Computes the velocity of the Sun projected on the direction of the source.
@@ -441,7 +446,7 @@ public:
 
     /** Computes the radial velocity of a source referred to the center of the Earth from
      * the radial velocity referred to an observer site on the surface of the earth 
-     * 
+     *
      * @param vtopo radial velocity of the source referred to the observer's site in km/s
      * @param vsite Velocity at which the observer moves referred to the center of the earth.
      * @return Radial velocity of the source referred the center of the earth in km/s
@@ -449,18 +454,18 @@ public:
     double vTopoToVGeo(double vtopo, double vsite[3]);
 
     /** Find the SkyPoint obtained by moving distance dist
-     * (arcseconds) away from the givenSkyPoint 
+     * (arcseconds) away from the givenSkyPoint
      *
      * @param dist Distance to move through in arcseconds
      * @param from The SkyPoint to move away from
      * @return a SkyPoint that is at the dist away from this SkyPoint in the direction away from from
      */
-    SkyPoint moveAway( const SkyPoint &from, double dist );
+    SkyPoint moveAway( const SkyPoint &from, double dist ) const;
 
     /**
      * @short Check if this point is circumpolar at the given geographic latitude
      */
-    bool checkCircumpolar( const dms *gLat );
+    bool checkCircumpolar( const dms *gLat ) const;
 
     /** Calculate refraction correction. Parameter and return value are in degrees */
     static double refractionCorr( double alt );
@@ -501,10 +506,11 @@ public:
     static const double altCrit;
 
 protected:
-    /**Precess this SkyPoint's catalog coordinates to the epoch described by the
-    	*given KSNumbers object.
-    	*@param num pointer to a KSNumbers object describing the target epoch.
-    	*/
+    /**
+     * Precess this SkyPoint's catalog coordinates to the epoch described by the
+     * given KSNumbers object.
+     * @param num pointer to a KSNumbers object describing the target epoch.
+     */
     void precess(const KSNumbers *num);
 
 private:
