@@ -35,12 +35,19 @@
 #include <QCheckBox>
 #include <QImage>
 
-EyepieceField::EyepieceField( QWidget *parent ) : KDialog( parent ) {
+EyepieceField::EyepieceField( QWidget *parent ) : QDialog( parent ) {
 
-    setCaption( i18n( "Eyepiece Field View" ) );
+    setWindowTitle( xi18n( "Eyepiece Field View" ) );
 
     QWidget *mainWidget = new QWidget( this );
-    setMainWidget( mainWidget );
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    mainLayout->addWidget(mainWidget);
+    setLayout(mainLayout);
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+    mainLayout->addWidget(buttonBox);
+    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+
     QVBoxLayout *rows = new QVBoxLayout;
     mainWidget->setLayout( rows );
 
@@ -60,9 +67,9 @@ EyepieceField::EyepieceField( QWidget *parent ) : KDialog( parent ) {
     imageLayout->addWidget( m_skyChartDisplay );
     imageLayout->addWidget( m_skyImageDisplay );
 
-    m_invertView = new QCheckBox( i18n( "Invert view" ), this );
-    m_flipView = new QCheckBox( i18n( "Flip view" ), this );
-    m_invertColors = new QCheckBox( i18n( "Invert colors" ), this );
+    m_invertView = new QCheckBox( xi18n( "Invert view" ), this );
+    m_flipView = new QCheckBox( xi18n( "Flip view" ), this );
+    m_invertColors = new QCheckBox( xi18n( "Invert colors" ), this );
     
     QHBoxLayout *optionsLayout = new QHBoxLayout;
     optionsLayout->addWidget( m_invertView );
@@ -78,7 +85,7 @@ EyepieceField::EyepieceField( QWidget *parent ) : KDialog( parent ) {
     m_rotationSlider->setTickInterval( 30 );
     m_rotationSlider->setPageStep( 30 );
 
-    QLabel *sliderLabel = new QLabel( i18n( "Rotation: " ), this );
+    QLabel *sliderLabel = new QLabel( xi18n( "Rotation: " ), this );
     
     QHBoxLayout *rotationLayout = new QHBoxLayout;
     rotationLayout->addWidget( sliderLabel );
@@ -86,12 +93,10 @@ EyepieceField::EyepieceField( QWidget *parent ) : KDialog( parent ) {
 
     rows->addLayout( rotationLayout );
 
-    connect( m_invertView, SIGNAL( stateChanged( int ) ), this, SLOT( render( int ) ) );
-    connect( m_flipView, SIGNAL( stateChanged( int ) ), this, SLOT( render( int ) ) );
-    connect( m_invertColors, SIGNAL( stateChanged( int ) ), this, SLOT( render( int ) ) );
-    connect( m_rotationSlider, SIGNAL( valueChanged( int ) ), this, SLOT( render( int ) ) );
-
-    setButtons( KDialog::Close );
+    connect( m_invertView, SIGNAL( stateChanged( int ) ), this, SLOT( render() ) );
+    connect( m_flipView, SIGNAL( stateChanged( int ) ), this, SLOT( render() ) );
+    connect( m_invertColors, SIGNAL( stateChanged( int ) ), this, SLOT( render() ) );
+    connect( m_rotationSlider, SIGNAL( valueChanged( int ) ), this, SLOT( render() ) );
 
     m_skyChart = 0;
     m_skyImage = 0;
@@ -163,7 +168,7 @@ void EyepieceField::showEyepieceField( SkyPoint *sp, FOV const * const fov, cons
     render();
 }
 
-void EyepieceField::render( int dummy ) {
+void EyepieceField::render() {
 
     QImage renderImage;
     QImage renderChart;
