@@ -20,13 +20,12 @@
 #include <QDesktopWidget>
 #include <QPixmap>
 #include <QPainter>
-#include <QPrinter>
-#include <QPrintDialog>
+#include <QtPrintSupport/QPrinter>
+#include <QtPrintSupport/QPrintDialog>
 #include <QFontInfo>
-#include <kdeprintdialog.h>
-#include <kdebug.h>
-#include <KPlotObject>
-#include <KPushButton>
+#include <QDebug>
+#include <KPlotting/KPlotObject>
+#include <QPushButton>
 
 #include "calendarwidget.h"
 #include "geolocation.h"
@@ -43,15 +42,28 @@ SkyCalendarUI::SkyCalendarUI( QWidget *parent )
 }
 
 SkyCalendar::SkyCalendar( QWidget *parent )
-    : KDialog( parent )
+    : QDialog( parent )
 {
     scUI = new SkyCalendarUI( this );
-    setMainWidget( scUI );
+
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+
+    mainLayout->addWidget(scUI);
+    setLayout(mainLayout);
     
     geo = KStarsData::Instance()->geo();
 
-    setCaption( i18n( "Sky Calendar" ) );
-    setButtons( KDialog::User1 | KDialog::Close );
+    setWindowTitle( xi18n( "Sky Calendar" ) );
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+    mainLayout->addWidget(buttonBox);
+    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+
+    QPushButton *printB = new QPushButton(QIcon::fromTheme("document-print"), xi18n("&Print..."));
+    printB->setToolTip(xi18n("Print the Sky Calendar"));
+    buttonBox->addButton(printB, QDialogButtonBox::ActionRole);
+    connect(printB, SIGNAL(clicked()), this, SLOT(slotPrint()));
+
     setModal( false );
 
     //Adjust minimum size for small screens:
@@ -63,13 +75,11 @@ SkyCalendar::SkyCalendar( QWidget *parent )
     scUI->Year->setValue( KStarsData::Instance()->lt().date().year() );
 
     scUI->LocationButton->setText( geo->fullName() );
-    setButtonGuiItem( KDialog::User1, KGuiItem( i18n("&Print..."), "document-print", i18n("Print the Sky Calendar") ) );
     
     scUI->CalendarView->setHorizon();
 
     connect( scUI->CreateButton, SIGNAL(clicked()), this, SLOT(slotFillCalendar()) );
     connect( scUI->LocationButton, SIGNAL(clicked()), this, SLOT(slotLocation()) );
-    connect( this, SIGNAL( user1Clicked() ), this, SLOT( slotPrint() ) );
 }
 
 SkyCalendar::~SkyCalendar() {
@@ -95,8 +105,8 @@ void SkyCalendar::slotFillCalendar() {
         addPlanetEvents( KSPlanetBase::URANUS );
     if ( scUI->checkBox_Neptune->isChecked() )
         addPlanetEvents( KSPlanetBase::NEPTUNE );
-    if ( scUI->checkBox_Pluto->isChecked() )
-        addPlanetEvents( KSPlanetBase::PLUTO );
+    //if ( scUI->checkBox_Pluto->isChecked() )
+        //addPlanetEvents( KSPlanetBase::PLUTO );
     
     scUI->CalendarView->update();
 }
@@ -264,7 +274,7 @@ void SkyCalendar::addPlanetEvents( int nPlanet ) {
            }
 
             if(needRiseLabel)
-                label = i18nc( "A planet rises from the horizon", "%1 rises", ksp->name() );
+                label = xi18nc( "A planet rises from the horizon", "%1 rises", ksp->name() );
             else
                 label = QString();
         // Add the current point to KPlotObject
@@ -282,7 +292,7 @@ void SkyCalendar::addPlanetEvents( int nPlanet ) {
            }
 
             if(needSetLabel)
-                label = i18nc( "A planet sets from the horizon", "%1 sets", ksp->name() );
+                label = xi18nc( "A planet sets from the horizon", "%1 sets", ksp->name() );
             else
                 label = QString();
 
@@ -300,7 +310,7 @@ void SkyCalendar::addPlanetEvents( int nPlanet ) {
            }
 
             if(needTransertLabel)
-                label = i18nc( "A planet transits across the meridian", "%1 transits", ksp->name() );
+                label = xi18nc( "A planet transits across the meridian", "%1 transits", ksp->name() );
             else
                 label = QString();
 
@@ -332,9 +342,11 @@ void SkyCalendar::slotPrint() {
     printer.setResolution( 300 );
 
     // Open print dialog
-    QPointer<QPrintDialog> dialog( KdePrint::createPrintDialog( &printer, this ) );
-    dialog->setWindowTitle( i18n( "Print sky calendar" ) );
-    if ( dialog->exec() == QDialog::Accepted ) {
+    //NOTE Changed from pointer to statically allocated object, what effect will it have?
+    //QPointer<QPrintDialog> dialog( KdePrint::createPrintDialog( &printer, this ) );
+    QPrintDialog dialog( &printer, this );
+    dialog.setWindowTitle( xi18n( "Print sky calendar" ) );
+    if ( dialog.exec() == QDialog::Accepted ) {
         // Change mouse cursor
         QApplication::setOverrideCursor( Qt::WaitCursor );
 
@@ -347,7 +359,7 @@ void SkyCalendar::slotPrint() {
 
         // Set text legend
         str_year.setNum( year() );
-        str_legend = i18n( "Sky Calendar" );
+        str_legend = xi18n( "Sky Calendar" );
         str_legend += "\n";
         str_legend += geo->fullName();
         str_legend += " - ";
@@ -384,7 +396,7 @@ void SkyCalendar::slotPrint() {
         // Restore mouse cursor
         QApplication::restoreOverrideCursor();
     }
-    delete dialog;
+    //delete dialog;
 }
 
 void SkyCalendar::slotLocation() {
@@ -407,4 +419,4 @@ GeoLocation* SkyCalendar::get_geo()
     return geo;
 }
 
-#include "skycalendar.moc"
+
