@@ -18,18 +18,18 @@
 #ifndef TIMESPINBOX_H
 #define TIMESPINBOX_H
 
-#include <KNumInput>
+#include <QSpinBox>
 
 class QStringList;
 
-/**@class TimeSpinBox
+/** @class TimeSpinBox
 	*Custom spinbox to handle selection of timestep values with variable units.
 	*@note this should only be used internally, embedded in a TimeStepBox widget.
 	*@author Jason Harris
 	*@version 1.0
 	*/
 
-class TimeSpinBox : public KIntSpinBox  {
+class TimeSpinBox : public QSpinBox  {
     Q_OBJECT
 public:
     /**Constructor */
@@ -51,7 +51,7 @@ public:
     	*/
     virtual int valueFromText( const QString &text ) const;
 
-    /**@return the current TimeStep setting */
+    /** @return the current TimeStep setting */
     float timeScale() const;
 
     void setDaysOnly( bool daysonly );
